import Foundation

struct Emoji: Hashable, Equatable, Identifiable, Codable, CustomStringConvertible {
    let character: String
    let name: String
    let category: Category
    let isNew: Bool
    let zwjGroup: String?   // nil for plain emoji, a String for ZWJ emoji group name (family, role, etc)
    var id: String { character }
    var description: String { character }

    // Can't use synthesized init because we want to validate the character String is one Character long
    init(character: String, name: String, category: Category, isNew: Bool, zwjGroup: String?) {
        // if the character String is not a single character, something is wrong
        // this should only happen if our Swift compiler version Unicode support is older than input Unicode character format
        self.character = character.count == 1 ? character : "\u{FFFD}"
        self.name = name
        self.category = category
        self.isNew = isNew
        self.zwjGroup = zwjGroup
    }

    struct Category: Hashable, Identifiable, Codable, CustomStringConvertible {
        let group: String
        let subgroup: String
        var id: String { "\(group) \(subgroup)" }
        var description: String { "\(group) (\(subgroup))" }
    }
}


let filtered = allEmojis.filter({ $0.name.localizedStandardContains("hole")})

dump(filtered)

print("\nDone", Date())








let allEmojis: [Emoji] = [
    .init(character: "😀", name: "grinning face", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😃", name: "grinning face with big eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😄", name: "grinning face with smiling eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😁", name: "beaming face with smiling eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😆", name: "grinning squinting face", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😅", name: "grinning face with sweat", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "🤣", name: "rolling on the floor laughing", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😂", name: "face with tears of joy", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "🙂", name: "slightly smiling face", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "🙃", name: "upside-down face", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "🫠", name: "melting face", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: true, zwjGroup: nil),
    .init(character: "😉", name: "winking face", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😊", name: "smiling face with smiling eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "😇", name: "smiling face with halo", category: .init(group: "Smileys & Emotion", subgroup: "face-smiling"), isNew: false, zwjGroup: nil),
    .init(character: "🥰", name: "smiling face with hearts", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "😍", name: "smiling face with heart-eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "🤩", name: "star-struck", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "😘", name: "face blowing a kiss", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "😗", name: "kissing face", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "☺️", name: "smiling face", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "😚", name: "kissing face with closed eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "😙", name: "kissing face with smiling eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "🥲", name: "smiling face with tear", category: .init(group: "Smileys & Emotion", subgroup: "face-affection"), isNew: false, zwjGroup: nil),
    .init(character: "😋", name: "face savoring food", category: .init(group: "Smileys & Emotion", subgroup: "face-tongue"), isNew: false, zwjGroup: nil),
    .init(character: "😛", name: "face with tongue", category: .init(group: "Smileys & Emotion", subgroup: "face-tongue"), isNew: false, zwjGroup: nil),
    .init(character: "😜", name: "winking face with tongue", category: .init(group: "Smileys & Emotion", subgroup: "face-tongue"), isNew: false, zwjGroup: nil),
    .init(character: "🤪", name: "zany face", category: .init(group: "Smileys & Emotion", subgroup: "face-tongue"), isNew: false, zwjGroup: nil),
    .init(character: "😝", name: "squinting face with tongue", category: .init(group: "Smileys & Emotion", subgroup: "face-tongue"), isNew: false, zwjGroup: nil),
    .init(character: "🤑", name: "money-mouth face", category: .init(group: "Smileys & Emotion", subgroup: "face-tongue"), isNew: false, zwjGroup: nil),
    .init(character: "🤗", name: "smiling face with open hands", category: .init(group: "Smileys & Emotion", subgroup: "face-hand"), isNew: true, zwjGroup: nil),
    .init(character: "🤭", name: "face with hand over mouth", category: .init(group: "Smileys & Emotion", subgroup: "face-hand"), isNew: false, zwjGroup: nil),
    .init(character: "🫢", name: "face with open eyes and hand over mouth", category: .init(group: "Smileys & Emotion", subgroup: "face-hand"), isNew: true, zwjGroup: nil),
    .init(character: "🫣", name: "face with peeking eye", category: .init(group: "Smileys & Emotion", subgroup: "face-hand"), isNew: true, zwjGroup: nil),
    .init(character: "🤫", name: "shushing face", category: .init(group: "Smileys & Emotion", subgroup: "face-hand"), isNew: false, zwjGroup: nil),
    .init(character: "🤔", name: "thinking face", category: .init(group: "Smileys & Emotion", subgroup: "face-hand"), isNew: false, zwjGroup: nil),
    .init(character: "🫡", name: "saluting face", category: .init(group: "Smileys & Emotion", subgroup: "face-hand"), isNew: true, zwjGroup: nil),
    .init(character: "🤐", name: "zipper-mouth face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "🤨", name: "face with raised eyebrow", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "😐", name: "neutral face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "😑", name: "expressionless face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "😶", name: "face without mouth", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "🫥", name: "dotted line face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: true, zwjGroup: nil),
    .init(character: "😶‍🌫️", name: "face in clouds", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: "Other"),
    .init(character: "😏", name: "smirking face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "😒", name: "unamused face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "🙄", name: "face with rolling eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "😬", name: "grimacing face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "😮‍💨", name: "face exhaling", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: "Other"),
    .init(character: "🤥", name: "lying face", category: .init(group: "Smileys & Emotion", subgroup: "face-neutral-skeptical"), isNew: false, zwjGroup: nil),
    .init(character: "😌", name: "relieved face", category: .init(group: "Smileys & Emotion", subgroup: "face-sleepy"), isNew: false, zwjGroup: nil),
    .init(character: "😔", name: "pensive face", category: .init(group: "Smileys & Emotion", subgroup: "face-sleepy"), isNew: false, zwjGroup: nil),
    .init(character: "😪", name: "sleepy face", category: .init(group: "Smileys & Emotion", subgroup: "face-sleepy"), isNew: false, zwjGroup: nil),
    .init(character: "🤤", name: "drooling face", category: .init(group: "Smileys & Emotion", subgroup: "face-sleepy"), isNew: false, zwjGroup: nil),
    .init(character: "😴", name: "sleeping face", category: .init(group: "Smileys & Emotion", subgroup: "face-sleepy"), isNew: false, zwjGroup: nil),
    .init(character: "😷", name: "face with medical mask", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🤒", name: "face with thermometer", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🤕", name: "face with head-bandage", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🤢", name: "nauseated face", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🤮", name: "face vomiting", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🤧", name: "sneezing face", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🥵", name: "hot face", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🥶", name: "cold face", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🥴", name: "woozy face", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "😵", name: "face with crossed-out eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: true, zwjGroup: nil),
    .init(character: "😵‍💫", name: "face with spiral eyes", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: "Other"),
    .init(character: "🤯", name: "exploding head", category: .init(group: "Smileys & Emotion", subgroup: "face-unwell"), isNew: false, zwjGroup: nil),
    .init(character: "🤠", name: "cowboy hat face", category: .init(group: "Smileys & Emotion", subgroup: "face-hat"), isNew: false, zwjGroup: nil),
    .init(character: "🥳", name: "partying face", category: .init(group: "Smileys & Emotion", subgroup: "face-hat"), isNew: false, zwjGroup: nil),
    .init(character: "🥸", name: "disguised face", category: .init(group: "Smileys & Emotion", subgroup: "face-hat"), isNew: false, zwjGroup: nil),
    .init(character: "😎", name: "smiling face with sunglasses", category: .init(group: "Smileys & Emotion", subgroup: "face-glasses"), isNew: false, zwjGroup: nil),
    .init(character: "🤓", name: "nerd face", category: .init(group: "Smileys & Emotion", subgroup: "face-glasses"), isNew: false, zwjGroup: nil),
    .init(character: "🧐", name: "face with monocle", category: .init(group: "Smileys & Emotion", subgroup: "face-glasses"), isNew: false, zwjGroup: nil),
    .init(character: "😕", name: "confused face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "🫤", name: "face with diagonal mouth", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: true, zwjGroup: nil),
    .init(character: "😟", name: "worried face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "🙁", name: "slightly frowning face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "☹️", name: "frowning face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😮", name: "face with open mouth", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😯", name: "hushed face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😲", name: "astonished face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😳", name: "flushed face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "🥺", name: "pleading face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "🥹", name: "face holding back tears", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: true, zwjGroup: nil),
    .init(character: "😦", name: "frowning face with open mouth", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😧", name: "anguished face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😨", name: "fearful face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😰", name: "anxious face with sweat", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😥", name: "sad but relieved face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😢", name: "crying face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😭", name: "loudly crying face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😱", name: "face screaming in fear", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😖", name: "confounded face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😣", name: "persevering face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😞", name: "disappointed face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😓", name: "downcast face with sweat", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😩", name: "weary face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😫", name: "tired face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "🥱", name: "yawning face", category: .init(group: "Smileys & Emotion", subgroup: "face-concerned"), isNew: false, zwjGroup: nil),
    .init(character: "😤", name: "face with steam from nose", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "😡", name: "pouting face", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "😠", name: "angry face", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "🤬", name: "face with symbols on mouth", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "😈", name: "smiling face with horns", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "👿", name: "angry face with horns", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "💀", name: "skull", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "☠️", name: "skull and crossbones", category: .init(group: "Smileys & Emotion", subgroup: "face-negative"), isNew: false, zwjGroup: nil),
    .init(character: "💩", name: "pile of poo", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "🤡", name: "clown face", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "👹", name: "ogre", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "👺", name: "goblin", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "👻", name: "ghost", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "👽", name: "alien", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "👾", name: "alien monster", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "🤖", name: "robot", category: .init(group: "Smileys & Emotion", subgroup: "face-costume"), isNew: false, zwjGroup: nil),
    .init(character: "😺", name: "grinning cat", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "😸", name: "grinning cat with smiling eyes", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "😹", name: "cat with tears of joy", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "😻", name: "smiling cat with heart-eyes", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "😼", name: "cat with wry smile", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "😽", name: "kissing cat", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "🙀", name: "weary cat", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "😿", name: "crying cat", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "😾", name: "pouting cat", category: .init(group: "Smileys & Emotion", subgroup: "cat-face"), isNew: false, zwjGroup: nil),
    .init(character: "🙈", name: "see-no-evil monkey", category: .init(group: "Smileys & Emotion", subgroup: "monkey-face"), isNew: false, zwjGroup: nil),
    .init(character: "🙉", name: "hear-no-evil monkey", category: .init(group: "Smileys & Emotion", subgroup: "monkey-face"), isNew: false, zwjGroup: nil),
    .init(character: "🙊", name: "speak-no-evil monkey", category: .init(group: "Smileys & Emotion", subgroup: "monkey-face"), isNew: false, zwjGroup: nil),
    .init(character: "💋", name: "kiss mark", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💌", name: "love letter", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💘", name: "heart with arrow", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💝", name: "heart with ribbon", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💖", name: "sparkling heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💗", name: "growing heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💓", name: "beating heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💞", name: "revolving hearts", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💕", name: "two hearts", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💟", name: "heart decoration", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "❣️", name: "heart exclamation", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💔", name: "broken heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "❤️‍🔥", name: "heart on fire", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: "Other"),
    .init(character: "❤️‍🩹", name: "mending heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: "Other"),
    .init(character: "❤️", name: "red heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "🧡", name: "orange heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💛", name: "yellow heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💚", name: "green heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💙", name: "blue heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💜", name: "purple heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "🤎", name: "brown heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "🖤", name: "black heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "🤍", name: "white heart", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💯", name: "hundred points", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💢", name: "anger symbol", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💥", name: "collision", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💫", name: "dizzy", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💦", name: "sweat droplets", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💨", name: "dashing away", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "🕳️", name: "hole", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💣", name: "bomb", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💬", name: "speech balloon", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "👁️‍🗨️", name: "eye in speech bubble", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: "Other"),
    .init(character: "🗨️", name: "left speech bubble", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "🗯️", name: "right anger bubble", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💭", name: "thought balloon", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "💤", name: "zzz", category: .init(group: "Smileys & Emotion", subgroup: "emotion"), isNew: false, zwjGroup: nil),
    .init(character: "👋", name: "waving hand", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "👋🏻", name: "waving hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "👋🏼", name: "waving hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "👋🏽", name: "waving hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "👋🏾", name: "waving hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "👋🏿", name: "waving hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🤚", name: "raised back of hand", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🤚🏻", name: "raised back of hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🤚🏼", name: "raised back of hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🤚🏽", name: "raised back of hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🤚🏾", name: "raised back of hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🤚🏿", name: "raised back of hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖐️", name: "hand with fingers splayed", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖐🏻", name: "hand with fingers splayed: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖐🏼", name: "hand with fingers splayed: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖐🏽", name: "hand with fingers splayed: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖐🏾", name: "hand with fingers splayed: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖐🏿", name: "hand with fingers splayed: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "✋", name: "raised hand", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "✋🏻", name: "raised hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "✋🏼", name: "raised hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "✋🏽", name: "raised hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "✋🏾", name: "raised hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "✋🏿", name: "raised hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖖", name: "vulcan salute", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖖🏻", name: "vulcan salute: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖖🏼", name: "vulcan salute: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖖🏽", name: "vulcan salute: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖖🏾", name: "vulcan salute: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🖖🏿", name: "vulcan salute: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: false, zwjGroup: nil),
    .init(character: "🫱", name: "rightwards hand", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫱🏻", name: "rightwards hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫱🏼", name: "rightwards hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫱🏽", name: "rightwards hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫱🏾", name: "rightwards hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫱🏿", name: "rightwards hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫲", name: "leftwards hand", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫲🏻", name: "leftwards hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫲🏼", name: "leftwards hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫲🏽", name: "leftwards hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫲🏾", name: "leftwards hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫲🏿", name: "leftwards hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫳", name: "palm down hand", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫳🏻", name: "palm down hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫳🏼", name: "palm down hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫳🏽", name: "palm down hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫳🏾", name: "palm down hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫳🏿", name: "palm down hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫴", name: "palm up hand", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫴🏻", name: "palm up hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫴🏼", name: "palm up hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫴🏽", name: "palm up hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫴🏾", name: "palm up hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "🫴🏿", name: "palm up hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-open"), isNew: true, zwjGroup: nil),
    .init(character: "👌", name: "OK hand", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "👌🏻", name: "OK hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "👌🏼", name: "OK hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "👌🏽", name: "OK hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "👌🏾", name: "OK hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "👌🏿", name: "OK hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤌", name: "pinched fingers", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤌🏻", name: "pinched fingers: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤌🏼", name: "pinched fingers: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤌🏽", name: "pinched fingers: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤌🏾", name: "pinched fingers: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤌🏿", name: "pinched fingers: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤏", name: "pinching hand", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤏🏻", name: "pinching hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤏🏼", name: "pinching hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤏🏽", name: "pinching hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤏🏾", name: "pinching hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤏🏿", name: "pinching hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "✌️", name: "victory hand", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "✌🏻", name: "victory hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "✌🏼", name: "victory hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "✌🏽", name: "victory hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "✌🏾", name: "victory hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "✌🏿", name: "victory hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤞", name: "crossed fingers", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤞🏻", name: "crossed fingers: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤞🏼", name: "crossed fingers: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤞🏽", name: "crossed fingers: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤞🏾", name: "crossed fingers: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤞🏿", name: "crossed fingers: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🫰", name: "hand with index finger and thumb crossed", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: true, zwjGroup: nil),
    .init(character: "🫰🏻", name: "hand with index finger and thumb crossed: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: true, zwjGroup: nil),
    .init(character: "🫰🏼", name: "hand with index finger and thumb crossed: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: true, zwjGroup: nil),
    .init(character: "🫰🏽", name: "hand with index finger and thumb crossed: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: true, zwjGroup: nil),
    .init(character: "🫰🏾", name: "hand with index finger and thumb crossed: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: true, zwjGroup: nil),
    .init(character: "🫰🏿", name: "hand with index finger and thumb crossed: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: true, zwjGroup: nil),
    .init(character: "🤟", name: "love-you gesture", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤟🏻", name: "love-you gesture: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤟🏼", name: "love-you gesture: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤟🏽", name: "love-you gesture: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤟🏾", name: "love-you gesture: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤟🏿", name: "love-you gesture: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤘", name: "sign of the horns", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤘🏻", name: "sign of the horns: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤘🏼", name: "sign of the horns: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤘🏽", name: "sign of the horns: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤘🏾", name: "sign of the horns: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤘🏿", name: "sign of the horns: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤙", name: "call me hand", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤙🏻", name: "call me hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤙🏼", name: "call me hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤙🏽", name: "call me hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤙🏾", name: "call me hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "🤙🏿", name: "call me hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-partial"), isNew: false, zwjGroup: nil),
    .init(character: "👈", name: "backhand index pointing left", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👈🏻", name: "backhand index pointing left: light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👈🏼", name: "backhand index pointing left: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👈🏽", name: "backhand index pointing left: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👈🏾", name: "backhand index pointing left: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👈🏿", name: "backhand index pointing left: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👉", name: "backhand index pointing right", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👉🏻", name: "backhand index pointing right: light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👉🏼", name: "backhand index pointing right: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👉🏽", name: "backhand index pointing right: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👉🏾", name: "backhand index pointing right: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👉🏿", name: "backhand index pointing right: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👆", name: "backhand index pointing up", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👆🏻", name: "backhand index pointing up: light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👆🏼", name: "backhand index pointing up: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👆🏽", name: "backhand index pointing up: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👆🏾", name: "backhand index pointing up: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👆🏿", name: "backhand index pointing up: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "🖕", name: "middle finger", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "🖕🏻", name: "middle finger: light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "🖕🏼", name: "middle finger: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "🖕🏽", name: "middle finger: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "🖕🏾", name: "middle finger: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "🖕🏿", name: "middle finger: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👇", name: "backhand index pointing down", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👇🏻", name: "backhand index pointing down: light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👇🏼", name: "backhand index pointing down: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👇🏽", name: "backhand index pointing down: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👇🏾", name: "backhand index pointing down: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "👇🏿", name: "backhand index pointing down: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "☝️", name: "index pointing up", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "☝🏻", name: "index pointing up: light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "☝🏼", name: "index pointing up: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "☝🏽", name: "index pointing up: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "☝🏾", name: "index pointing up: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "☝🏿", name: "index pointing up: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: false, zwjGroup: nil),
    .init(character: "🫵", name: "index pointing at the viewer", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: true, zwjGroup: nil),
    .init(character: "🫵🏻", name: "index pointing at the viewer: light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: true, zwjGroup: nil),
    .init(character: "🫵🏼", name: "index pointing at the viewer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: true, zwjGroup: nil),
    .init(character: "🫵🏽", name: "index pointing at the viewer: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: true, zwjGroup: nil),
    .init(character: "🫵🏾", name: "index pointing at the viewer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: true, zwjGroup: nil),
    .init(character: "🫵🏿", name: "index pointing at the viewer: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-single-finger"), isNew: true, zwjGroup: nil),
    .init(character: "👍", name: "thumbs up", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👍🏻", name: "thumbs up: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👍🏼", name: "thumbs up: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👍🏽", name: "thumbs up: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👍🏾", name: "thumbs up: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👍🏿", name: "thumbs up: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👎", name: "thumbs down", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👎🏻", name: "thumbs down: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👎🏼", name: "thumbs down: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👎🏽", name: "thumbs down: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👎🏾", name: "thumbs down: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👎🏿", name: "thumbs down: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "✊", name: "raised fist", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "✊🏻", name: "raised fist: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "✊🏼", name: "raised fist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "✊🏽", name: "raised fist: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "✊🏾", name: "raised fist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "✊🏿", name: "raised fist: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👊", name: "oncoming fist", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👊🏻", name: "oncoming fist: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👊🏼", name: "oncoming fist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👊🏽", name: "oncoming fist: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👊🏾", name: "oncoming fist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👊🏿", name: "oncoming fist: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤛", name: "left-facing fist", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤛🏻", name: "left-facing fist: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤛🏼", name: "left-facing fist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤛🏽", name: "left-facing fist: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤛🏾", name: "left-facing fist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤛🏿", name: "left-facing fist: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤜", name: "right-facing fist", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤜🏻", name: "right-facing fist: light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤜🏼", name: "right-facing fist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤜🏽", name: "right-facing fist: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤜🏾", name: "right-facing fist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "🤜🏿", name: "right-facing fist: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-fingers-closed"), isNew: false, zwjGroup: nil),
    .init(character: "👏", name: "clapping hands", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👏🏻", name: "clapping hands: light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👏🏼", name: "clapping hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👏🏽", name: "clapping hands: medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👏🏾", name: "clapping hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👏🏿", name: "clapping hands: dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙌", name: "raising hands", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙌🏻", name: "raising hands: light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙌🏼", name: "raising hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙌🏽", name: "raising hands: medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙌🏾", name: "raising hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙌🏿", name: "raising hands: dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🫶", name: "heart hands", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🫶🏻", name: "heart hands: light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🫶🏼", name: "heart hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🫶🏽", name: "heart hands: medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🫶🏾", name: "heart hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🫶🏿", name: "heart hands: dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "👐", name: "open hands", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👐🏻", name: "open hands: light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👐🏼", name: "open hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👐🏽", name: "open hands: medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👐🏾", name: "open hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "👐🏿", name: "open hands: dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤲", name: "palms up together", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤲🏻", name: "palms up together: light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤲🏼", name: "palms up together: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤲🏽", name: "palms up together: medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤲🏾", name: "palms up together: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤲🏿", name: "palms up together: dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤝", name: "handshake", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🤝🏻", name: "handshake: light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🤝🏼", name: "handshake: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🤝🏽", name: "handshake: medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🤝🏾", name: "handshake: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🤝🏿", name: "handshake: dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: nil),
    .init(character: "🫱🏻‍🫲🏼", name: "handshake: light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏻‍🫲🏽", name: "handshake: light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏻‍🫲🏾", name: "handshake: light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏻‍🫲🏿", name: "handshake: light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏼‍🫲🏻", name: "handshake: medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏼‍🫲🏽", name: "handshake: medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏼‍🫲🏾", name: "handshake: medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏼‍🫲🏿", name: "handshake: medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏽‍🫲🏻", name: "handshake: medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏽‍🫲🏼", name: "handshake: medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏽‍🫲🏾", name: "handshake: medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏽‍🫲🏿", name: "handshake: medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏾‍🫲🏻", name: "handshake: medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏾‍🫲🏼", name: "handshake: medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏾‍🫲🏽", name: "handshake: medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏾‍🫲🏿", name: "handshake: medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏿‍🫲🏻", name: "handshake: dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏿‍🫲🏼", name: "handshake: dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏿‍🫲🏽", name: "handshake: dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🫱🏿‍🫲🏾", name: "handshake: dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: true, zwjGroup: "Family"),
    .init(character: "🙏", name: "folded hands", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙏🏻", name: "folded hands: light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙏🏼", name: "folded hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙏🏽", name: "folded hands: medium skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙏🏾", name: "folded hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "🙏🏿", name: "folded hands: dark skin tone", category: .init(group: "People & Body", subgroup: "hands"), isNew: false, zwjGroup: nil),
    .init(character: "✍️", name: "writing hand", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "✍🏻", name: "writing hand: light skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "✍🏼", name: "writing hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "✍🏽", name: "writing hand: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "✍🏾", name: "writing hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "✍🏿", name: "writing hand: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "💅", name: "nail polish", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "💅🏻", name: "nail polish: light skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "💅🏼", name: "nail polish: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "💅🏽", name: "nail polish: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "💅🏾", name: "nail polish: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "💅🏿", name: "nail polish: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "🤳", name: "selfie", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "🤳🏻", name: "selfie: light skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "🤳🏼", name: "selfie: medium-light skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "🤳🏽", name: "selfie: medium skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "🤳🏾", name: "selfie: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "🤳🏿", name: "selfie: dark skin tone", category: .init(group: "People & Body", subgroup: "hand-prop"), isNew: false, zwjGroup: nil),
    .init(character: "💪", name: "flexed biceps", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "💪🏻", name: "flexed biceps: light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "💪🏼", name: "flexed biceps: medium-light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "💪🏽", name: "flexed biceps: medium skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "💪🏾", name: "flexed biceps: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "💪🏿", name: "flexed biceps: dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦾", name: "mechanical arm", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦿", name: "mechanical leg", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦵", name: "leg", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦵🏻", name: "leg: light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦵🏼", name: "leg: medium-light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦵🏽", name: "leg: medium skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦵🏾", name: "leg: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦵🏿", name: "leg: dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦶", name: "foot", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦶🏻", name: "foot: light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦶🏼", name: "foot: medium-light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦶🏽", name: "foot: medium skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦶🏾", name: "foot: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦶🏿", name: "foot: dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👂", name: "ear", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👂🏻", name: "ear: light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👂🏼", name: "ear: medium-light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👂🏽", name: "ear: medium skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👂🏾", name: "ear: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👂🏿", name: "ear: dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦻", name: "ear with hearing aid", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦻🏻", name: "ear with hearing aid: light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦻🏼", name: "ear with hearing aid: medium-light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦻🏽", name: "ear with hearing aid: medium skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦻🏾", name: "ear with hearing aid: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦻🏿", name: "ear with hearing aid: dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👃", name: "nose", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👃🏻", name: "nose: light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👃🏼", name: "nose: medium-light skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👃🏽", name: "nose: medium skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👃🏾", name: "nose: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👃🏿", name: "nose: dark skin tone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🧠", name: "brain", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🫀", name: "anatomical heart", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🫁", name: "lungs", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦷", name: "tooth", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🦴", name: "bone", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👀", name: "eyes", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👁️", name: "eye", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👅", name: "tongue", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "👄", name: "mouth", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: false, zwjGroup: nil),
    .init(character: "🫦", name: "biting lip", category: .init(group: "People & Body", subgroup: "body-parts"), isNew: true, zwjGroup: nil),
    .init(character: "👶", name: "baby", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👶🏻", name: "baby: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👶🏼", name: "baby: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👶🏽", name: "baby: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👶🏾", name: "baby: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👶🏿", name: "baby: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧒", name: "child", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧒🏻", name: "child: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧒🏼", name: "child: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧒🏽", name: "child: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧒🏾", name: "child: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧒🏿", name: "child: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👦", name: "boy", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👦🏻", name: "boy: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👦🏼", name: "boy: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👦🏽", name: "boy: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👦🏾", name: "boy: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👦🏿", name: "boy: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👧", name: "girl", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👧🏻", name: "girl: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👧🏼", name: "girl: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👧🏽", name: "girl: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👧🏾", name: "girl: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👧🏿", name: "girl: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧑", name: "person", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧑🏻", name: "person: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧑🏼", name: "person: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧑🏽", name: "person: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧑🏾", name: "person: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧑🏿", name: "person: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👱", name: "person: blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👱🏻", name: "person: light skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👱🏼", name: "person: medium-light skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👱🏽", name: "person: medium skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👱🏾", name: "person: medium-dark skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👱🏿", name: "person: dark skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👨", name: "man", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏻", name: "man: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏼", name: "man: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏽", name: "man: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏾", name: "man: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏿", name: "man: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧔", name: "person: beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧔🏻", name: "person: light skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧔🏼", name: "person: medium-light skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧔🏽", name: "person: medium skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧔🏾", name: "person: medium-dark skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧔🏿", name: "person: dark skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧔‍♂️", name: "man: beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏻‍♂️", name: "man: light skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏼‍♂️", name: "man: medium-light skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏽‍♂️", name: "man: medium skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏾‍♂️", name: "man: medium-dark skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏿‍♂️", name: "man: dark skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔‍♀️", name: "woman: beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏻‍♀️", name: "woman: light skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏼‍♀️", name: "woman: medium-light skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏽‍♀️", name: "woman: medium skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏾‍♀️", name: "woman: medium-dark skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧔🏿‍♀️", name: "woman: dark skin tone, beard", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👨‍🦰", name: "man: red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏻‍🦰", name: "man: light skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏼‍🦰", name: "man: medium-light skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏽‍🦰", name: "man: medium skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏾‍🦰", name: "man: medium-dark skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏿‍🦰", name: "man: dark skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨‍🦱", name: "man: curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏻‍🦱", name: "man: light skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏼‍🦱", name: "man: medium-light skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏽‍🦱", name: "man: medium skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏾‍🦱", name: "man: medium-dark skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏿‍🦱", name: "man: dark skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨‍🦳", name: "man: white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏻‍🦳", name: "man: light skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏼‍🦳", name: "man: medium-light skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏽‍🦳", name: "man: medium skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏾‍🦳", name: "man: medium-dark skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏿‍🦳", name: "man: dark skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨‍🦲", name: "man: bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏻‍🦲", name: "man: light skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏼‍🦲", name: "man: medium-light skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏽‍🦲", name: "man: medium skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏾‍🦲", name: "man: medium-dark skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👨🏿‍🦲", name: "man: dark skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩", name: "woman", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏻", name: "woman: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏼", name: "woman: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏽", name: "woman: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏾", name: "woman: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏿", name: "woman: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👩‍🦰", name: "woman: red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏻‍🦰", name: "woman: light skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏼‍🦰", name: "woman: medium-light skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏽‍🦰", name: "woman: medium skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏾‍🦰", name: "woman: medium-dark skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏿‍🦰", name: "woman: dark skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑‍🦰", name: "person: red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏻‍🦰", name: "person: light skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏼‍🦰", name: "person: medium-light skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏽‍🦰", name: "person: medium skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏾‍🦰", name: "person: medium-dark skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏿‍🦰", name: "person: dark skin tone, red hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩‍🦱", name: "woman: curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏻‍🦱", name: "woman: light skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏼‍🦱", name: "woman: medium-light skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏽‍🦱", name: "woman: medium skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏾‍🦱", name: "woman: medium-dark skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏿‍🦱", name: "woman: dark skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑‍🦱", name: "person: curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏻‍🦱", name: "person: light skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏼‍🦱", name: "person: medium-light skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏽‍🦱", name: "person: medium skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏾‍🦱", name: "person: medium-dark skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏿‍🦱", name: "person: dark skin tone, curly hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩‍🦳", name: "woman: white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏻‍🦳", name: "woman: light skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏼‍🦳", name: "woman: medium-light skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏽‍🦳", name: "woman: medium skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏾‍🦳", name: "woman: medium-dark skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏿‍🦳", name: "woman: dark skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑‍🦳", name: "person: white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏻‍🦳", name: "person: light skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏼‍🦳", name: "person: medium-light skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏽‍🦳", name: "person: medium skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏾‍🦳", name: "person: medium-dark skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏿‍🦳", name: "person: dark skin tone, white hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩‍🦲", name: "woman: bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏻‍🦲", name: "woman: light skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏼‍🦲", name: "woman: medium-light skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏽‍🦲", name: "woman: medium skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏾‍🦲", name: "woman: medium-dark skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👩🏿‍🦲", name: "woman: dark skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑‍🦲", name: "person: bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏻‍🦲", name: "person: light skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏼‍🦲", name: "person: medium-light skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏽‍🦲", name: "person: medium skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏾‍🦲", name: "person: medium-dark skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "🧑🏿‍🦲", name: "person: dark skin tone, bald", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Hair"),
    .init(character: "👱‍♀️", name: "woman: blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏻‍♀️", name: "woman: light skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏼‍♀️", name: "woman: medium-light skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏽‍♀️", name: "woman: medium skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏾‍♀️", name: "woman: medium-dark skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏿‍♀️", name: "woman: dark skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱‍♂️", name: "man: blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏻‍♂️", name: "man: light skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏼‍♂️", name: "man: medium-light skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏽‍♂️", name: "man: medium skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏾‍♂️", name: "man: medium-dark skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👱🏿‍♂️", name: "man: dark skin tone, blond hair", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧓", name: "older person", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧓🏻", name: "older person: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧓🏼", name: "older person: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧓🏽", name: "older person: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧓🏾", name: "older person: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🧓🏿", name: "older person: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👴", name: "old man", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👴🏻", name: "old man: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👴🏼", name: "old man: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👴🏽", name: "old man: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👴🏾", name: "old man: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👴🏿", name: "old man: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👵", name: "old woman", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👵🏻", name: "old woman: light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👵🏼", name: "old woman: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👵🏽", name: "old woman: medium skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👵🏾", name: "old woman: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "👵🏿", name: "old woman: dark skin tone", category: .init(group: "People & Body", subgroup: "person"), isNew: false, zwjGroup: nil),
    .init(character: "🙍", name: "person frowning", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙍🏻", name: "person frowning: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙍🏼", name: "person frowning: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙍🏽", name: "person frowning: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙍🏾", name: "person frowning: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙍🏿", name: "person frowning: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙍‍♂️", name: "man frowning", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏻‍♂️", name: "man frowning: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏼‍♂️", name: "man frowning: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏽‍♂️", name: "man frowning: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏾‍♂️", name: "man frowning: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏿‍♂️", name: "man frowning: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍‍♀️", name: "woman frowning", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏻‍♀️", name: "woman frowning: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏼‍♀️", name: "woman frowning: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏽‍♀️", name: "woman frowning: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏾‍♀️", name: "woman frowning: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙍🏿‍♀️", name: "woman frowning: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎", name: "person pouting", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙎🏻", name: "person pouting: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙎🏼", name: "person pouting: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙎🏽", name: "person pouting: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙎🏾", name: "person pouting: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙎🏿", name: "person pouting: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙎‍♂️", name: "man pouting", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏻‍♂️", name: "man pouting: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏼‍♂️", name: "man pouting: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏽‍♂️", name: "man pouting: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏾‍♂️", name: "man pouting: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏿‍♂️", name: "man pouting: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎‍♀️", name: "woman pouting", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏻‍♀️", name: "woman pouting: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏼‍♀️", name: "woman pouting: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏽‍♀️", name: "woman pouting: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏾‍♀️", name: "woman pouting: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙎🏿‍♀️", name: "woman pouting: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅", name: "person gesturing NO", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙅🏻", name: "person gesturing NO: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙅🏼", name: "person gesturing NO: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙅🏽", name: "person gesturing NO: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙅🏾", name: "person gesturing NO: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙅🏿", name: "person gesturing NO: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙅‍♂️", name: "man gesturing NO", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏻‍♂️", name: "man gesturing NO: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏼‍♂️", name: "man gesturing NO: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏽‍♂️", name: "man gesturing NO: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏾‍♂️", name: "man gesturing NO: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏿‍♂️", name: "man gesturing NO: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅‍♀️", name: "woman gesturing NO", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏻‍♀️", name: "woman gesturing NO: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏼‍♀️", name: "woman gesturing NO: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏽‍♀️", name: "woman gesturing NO: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏾‍♀️", name: "woman gesturing NO: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙅🏿‍♀️", name: "woman gesturing NO: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆", name: "person gesturing OK", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙆🏻", name: "person gesturing OK: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙆🏼", name: "person gesturing OK: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙆🏽", name: "person gesturing OK: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙆🏾", name: "person gesturing OK: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙆🏿", name: "person gesturing OK: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙆‍♂️", name: "man gesturing OK", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏻‍♂️", name: "man gesturing OK: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏼‍♂️", name: "man gesturing OK: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏽‍♂️", name: "man gesturing OK: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏾‍♂️", name: "man gesturing OK: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏿‍♂️", name: "man gesturing OK: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆‍♀️", name: "woman gesturing OK", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏻‍♀️", name: "woman gesturing OK: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏼‍♀️", name: "woman gesturing OK: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏽‍♀️", name: "woman gesturing OK: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏾‍♀️", name: "woman gesturing OK: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙆🏿‍♀️", name: "woman gesturing OK: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁", name: "person tipping hand", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "💁🏻", name: "person tipping hand: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "💁🏼", name: "person tipping hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "💁🏽", name: "person tipping hand: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "💁🏾", name: "person tipping hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "💁🏿", name: "person tipping hand: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "💁‍♂️", name: "man tipping hand", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏻‍♂️", name: "man tipping hand: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏼‍♂️", name: "man tipping hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏽‍♂️", name: "man tipping hand: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏾‍♂️", name: "man tipping hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏿‍♂️", name: "man tipping hand: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁‍♀️", name: "woman tipping hand", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏻‍♀️", name: "woman tipping hand: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏼‍♀️", name: "woman tipping hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏽‍♀️", name: "woman tipping hand: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏾‍♀️", name: "woman tipping hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💁🏿‍♀️", name: "woman tipping hand: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋", name: "person raising hand", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙋🏻", name: "person raising hand: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙋🏼", name: "person raising hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙋🏽", name: "person raising hand: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙋🏾", name: "person raising hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙋🏿", name: "person raising hand: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙋‍♂️", name: "man raising hand", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏻‍♂️", name: "man raising hand: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏼‍♂️", name: "man raising hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏽‍♂️", name: "man raising hand: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏾‍♂️", name: "man raising hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏿‍♂️", name: "man raising hand: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋‍♀️", name: "woman raising hand", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏻‍♀️", name: "woman raising hand: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏼‍♀️", name: "woman raising hand: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏽‍♀️", name: "woman raising hand: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏾‍♀️", name: "woman raising hand: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙋🏿‍♀️", name: "woman raising hand: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏", name: "deaf person", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🧏🏻", name: "deaf person: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🧏🏼", name: "deaf person: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🧏🏽", name: "deaf person: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🧏🏾", name: "deaf person: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🧏🏿", name: "deaf person: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🧏‍♂️", name: "deaf man", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏻‍♂️", name: "deaf man: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏼‍♂️", name: "deaf man: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏽‍♂️", name: "deaf man: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏾‍♂️", name: "deaf man: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏿‍♂️", name: "deaf man: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏‍♀️", name: "deaf woman", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏻‍♀️", name: "deaf woman: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏼‍♀️", name: "deaf woman: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏽‍♀️", name: "deaf woman: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏾‍♀️", name: "deaf woman: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧏🏿‍♀️", name: "deaf woman: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇", name: "person bowing", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙇🏻", name: "person bowing: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙇🏼", name: "person bowing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙇🏽", name: "person bowing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙇🏾", name: "person bowing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙇🏿", name: "person bowing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🙇‍♂️", name: "man bowing", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏻‍♂️", name: "man bowing: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏼‍♂️", name: "man bowing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏽‍♂️", name: "man bowing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏾‍♂️", name: "man bowing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏿‍♂️", name: "man bowing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇‍♀️", name: "woman bowing", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏻‍♀️", name: "woman bowing: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏼‍♀️", name: "woman bowing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏽‍♀️", name: "woman bowing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏾‍♀️", name: "woman bowing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🙇🏿‍♀️", name: "woman bowing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦", name: "person facepalming", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤦🏻", name: "person facepalming: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤦🏼", name: "person facepalming: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤦🏽", name: "person facepalming: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤦🏾", name: "person facepalming: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤦🏿", name: "person facepalming: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤦‍♂️", name: "man facepalming", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏻‍♂️", name: "man facepalming: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏼‍♂️", name: "man facepalming: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏽‍♂️", name: "man facepalming: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏾‍♂️", name: "man facepalming: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏿‍♂️", name: "man facepalming: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦‍♀️", name: "woman facepalming", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏻‍♀️", name: "woman facepalming: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏼‍♀️", name: "woman facepalming: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏽‍♀️", name: "woman facepalming: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏾‍♀️", name: "woman facepalming: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤦🏿‍♀️", name: "woman facepalming: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷", name: "person shrugging", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤷🏻", name: "person shrugging: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤷🏼", name: "person shrugging: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤷🏽", name: "person shrugging: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤷🏾", name: "person shrugging: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤷🏿", name: "person shrugging: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: nil),
    .init(character: "🤷‍♂️", name: "man shrugging", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏻‍♂️", name: "man shrugging: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏼‍♂️", name: "man shrugging: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏽‍♂️", name: "man shrugging: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏾‍♂️", name: "man shrugging: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏿‍♂️", name: "man shrugging: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷‍♀️", name: "woman shrugging", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏻‍♀️", name: "woman shrugging: light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏼‍♀️", name: "woman shrugging: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏽‍♀️", name: "woman shrugging: medium skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏾‍♀️", name: "woman shrugging: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤷🏿‍♀️", name: "woman shrugging: dark skin tone", category: .init(group: "People & Body", subgroup: "person-gesture"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧑‍⚕️", name: "health worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍⚕️", name: "health worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍⚕️", name: "health worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍⚕️", name: "health worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍⚕️", name: "health worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍⚕️", name: "health worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍⚕️", name: "man health worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍⚕️", name: "man health worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍⚕️", name: "man health worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍⚕️", name: "man health worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍⚕️", name: "man health worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍⚕️", name: "man health worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍⚕️", name: "woman health worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍⚕️", name: "woman health worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍⚕️", name: "woman health worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍⚕️", name: "woman health worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍⚕️", name: "woman health worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍⚕️", name: "woman health worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🎓", name: "student", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🎓", name: "student: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🎓", name: "student: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🎓", name: "student: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🎓", name: "student: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🎓", name: "student: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🎓", name: "man student", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🎓", name: "man student: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🎓", name: "man student: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🎓", name: "man student: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🎓", name: "man student: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🎓", name: "man student: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🎓", name: "woman student", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🎓", name: "woman student: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🎓", name: "woman student: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🎓", name: "woman student: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🎓", name: "woman student: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🎓", name: "woman student: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🏫", name: "teacher", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🏫", name: "teacher: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🏫", name: "teacher: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🏫", name: "teacher: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🏫", name: "teacher: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🏫", name: "teacher: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🏫", name: "man teacher", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🏫", name: "man teacher: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🏫", name: "man teacher: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🏫", name: "man teacher: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🏫", name: "man teacher: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🏫", name: "man teacher: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🏫", name: "woman teacher", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🏫", name: "woman teacher: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🏫", name: "woman teacher: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🏫", name: "woman teacher: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🏫", name: "woman teacher: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🏫", name: "woman teacher: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍⚖️", name: "judge", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍⚖️", name: "judge: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍⚖️", name: "judge: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍⚖️", name: "judge: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍⚖️", name: "judge: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍⚖️", name: "judge: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍⚖️", name: "man judge", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍⚖️", name: "man judge: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍⚖️", name: "man judge: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍⚖️", name: "man judge: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍⚖️", name: "man judge: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍⚖️", name: "man judge: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍⚖️", name: "woman judge", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍⚖️", name: "woman judge: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍⚖️", name: "woman judge: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍⚖️", name: "woman judge: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍⚖️", name: "woman judge: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍⚖️", name: "woman judge: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🌾", name: "farmer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🌾", name: "farmer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🌾", name: "farmer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🌾", name: "farmer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🌾", name: "farmer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🌾", name: "farmer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🌾", name: "man farmer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🌾", name: "man farmer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🌾", name: "man farmer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🌾", name: "man farmer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🌾", name: "man farmer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🌾", name: "man farmer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🌾", name: "woman farmer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🌾", name: "woman farmer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🌾", name: "woman farmer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🌾", name: "woman farmer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🌾", name: "woman farmer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🌾", name: "woman farmer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🍳", name: "cook", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🍳", name: "cook: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🍳", name: "cook: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🍳", name: "cook: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🍳", name: "cook: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🍳", name: "cook: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🍳", name: "man cook", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🍳", name: "man cook: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🍳", name: "man cook: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🍳", name: "man cook: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🍳", name: "man cook: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🍳", name: "man cook: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🍳", name: "woman cook", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🍳", name: "woman cook: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🍳", name: "woman cook: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🍳", name: "woman cook: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🍳", name: "woman cook: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🍳", name: "woman cook: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🔧", name: "mechanic", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🔧", name: "mechanic: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🔧", name: "mechanic: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🔧", name: "mechanic: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🔧", name: "mechanic: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🔧", name: "mechanic: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🔧", name: "man mechanic", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🔧", name: "man mechanic: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🔧", name: "man mechanic: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🔧", name: "man mechanic: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🔧", name: "man mechanic: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🔧", name: "man mechanic: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🔧", name: "woman mechanic", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🔧", name: "woman mechanic: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🔧", name: "woman mechanic: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🔧", name: "woman mechanic: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🔧", name: "woman mechanic: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🔧", name: "woman mechanic: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🏭", name: "factory worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🏭", name: "factory worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🏭", name: "factory worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🏭", name: "factory worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🏭", name: "factory worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🏭", name: "factory worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🏭", name: "man factory worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🏭", name: "man factory worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🏭", name: "man factory worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🏭", name: "man factory worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🏭", name: "man factory worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🏭", name: "man factory worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🏭", name: "woman factory worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🏭", name: "woman factory worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🏭", name: "woman factory worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🏭", name: "woman factory worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🏭", name: "woman factory worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🏭", name: "woman factory worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍💼", name: "office worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍💼", name: "office worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍💼", name: "office worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍💼", name: "office worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍💼", name: "office worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍💼", name: "office worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍💼", name: "man office worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍💼", name: "man office worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍💼", name: "man office worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍💼", name: "man office worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍💼", name: "man office worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍💼", name: "man office worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍💼", name: "woman office worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍💼", name: "woman office worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍💼", name: "woman office worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍💼", name: "woman office worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍💼", name: "woman office worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍💼", name: "woman office worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🔬", name: "scientist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🔬", name: "scientist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🔬", name: "scientist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🔬", name: "scientist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🔬", name: "scientist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🔬", name: "scientist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🔬", name: "man scientist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🔬", name: "man scientist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🔬", name: "man scientist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🔬", name: "man scientist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🔬", name: "man scientist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🔬", name: "man scientist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🔬", name: "woman scientist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🔬", name: "woman scientist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🔬", name: "woman scientist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🔬", name: "woman scientist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🔬", name: "woman scientist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🔬", name: "woman scientist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍💻", name: "technologist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍💻", name: "technologist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍💻", name: "technologist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍💻", name: "technologist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍💻", name: "technologist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍💻", name: "technologist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍💻", name: "man technologist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍💻", name: "man technologist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍💻", name: "man technologist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍💻", name: "man technologist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍💻", name: "man technologist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍💻", name: "man technologist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍💻", name: "woman technologist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍💻", name: "woman technologist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍💻", name: "woman technologist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍💻", name: "woman technologist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍💻", name: "woman technologist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍💻", name: "woman technologist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🎤", name: "singer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🎤", name: "singer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🎤", name: "singer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🎤", name: "singer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🎤", name: "singer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🎤", name: "singer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🎤", name: "man singer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🎤", name: "man singer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🎤", name: "man singer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🎤", name: "man singer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🎤", name: "man singer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🎤", name: "man singer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🎤", name: "woman singer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🎤", name: "woman singer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🎤", name: "woman singer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🎤", name: "woman singer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🎤", name: "woman singer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🎤", name: "woman singer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🎨", name: "artist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🎨", name: "artist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🎨", name: "artist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🎨", name: "artist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🎨", name: "artist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🎨", name: "artist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🎨", name: "man artist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🎨", name: "man artist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🎨", name: "man artist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🎨", name: "man artist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🎨", name: "man artist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🎨", name: "man artist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🎨", name: "woman artist", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🎨", name: "woman artist: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🎨", name: "woman artist: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🎨", name: "woman artist: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🎨", name: "woman artist: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🎨", name: "woman artist: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍✈️", name: "pilot", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍✈️", name: "pilot: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍✈️", name: "pilot: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍✈️", name: "pilot: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍✈️", name: "pilot: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍✈️", name: "pilot: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍✈️", name: "man pilot", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍✈️", name: "man pilot: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍✈️", name: "man pilot: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍✈️", name: "man pilot: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍✈️", name: "man pilot: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍✈️", name: "man pilot: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍✈️", name: "woman pilot", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍✈️", name: "woman pilot: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍✈️", name: "woman pilot: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍✈️", name: "woman pilot: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍✈️", name: "woman pilot: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍✈️", name: "woman pilot: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🚀", name: "astronaut", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🚀", name: "astronaut: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🚀", name: "astronaut: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🚀", name: "astronaut: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🚀", name: "astronaut: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🚀", name: "astronaut: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🚀", name: "man astronaut", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🚀", name: "man astronaut: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🚀", name: "man astronaut: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🚀", name: "man astronaut: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🚀", name: "man astronaut: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🚀", name: "man astronaut: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🚀", name: "woman astronaut", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🚀", name: "woman astronaut: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🚀", name: "woman astronaut: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🚀", name: "woman astronaut: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🚀", name: "woman astronaut: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🚀", name: "woman astronaut: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🚒", name: "firefighter", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🚒", name: "firefighter: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🚒", name: "firefighter: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🚒", name: "firefighter: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🚒", name: "firefighter: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🚒", name: "firefighter: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🚒", name: "man firefighter", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🚒", name: "man firefighter: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🚒", name: "man firefighter: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🚒", name: "man firefighter: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🚒", name: "man firefighter: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🚒", name: "man firefighter: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🚒", name: "woman firefighter", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🚒", name: "woman firefighter: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🚒", name: "woman firefighter: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🚒", name: "woman firefighter: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🚒", name: "woman firefighter: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🚒", name: "woman firefighter: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👮", name: "police officer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👮🏻", name: "police officer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👮🏼", name: "police officer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👮🏽", name: "police officer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👮🏾", name: "police officer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👮🏿", name: "police officer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👮‍♂️", name: "man police officer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏻‍♂️", name: "man police officer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏼‍♂️", name: "man police officer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏽‍♂️", name: "man police officer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏾‍♂️", name: "man police officer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏿‍♂️", name: "man police officer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮‍♀️", name: "woman police officer", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏻‍♀️", name: "woman police officer: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏼‍♀️", name: "woman police officer: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏽‍♀️", name: "woman police officer: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏾‍♀️", name: "woman police officer: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👮🏿‍♀️", name: "woman police officer: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵️", name: "detective", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🕵🏻", name: "detective: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🕵🏼", name: "detective: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🕵🏽", name: "detective: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🕵🏾", name: "detective: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🕵🏿", name: "detective: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🕵️‍♂️", name: "man detective", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏻‍♂️", name: "man detective: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏼‍♂️", name: "man detective: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏽‍♂️", name: "man detective: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏾‍♂️", name: "man detective: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏿‍♂️", name: "man detective: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵️‍♀️", name: "woman detective", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏻‍♀️", name: "woman detective: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏼‍♀️", name: "woman detective: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏽‍♀️", name: "woman detective: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏾‍♀️", name: "woman detective: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🕵🏿‍♀️", name: "woman detective: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂", name: "guard", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "💂🏻", name: "guard: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "💂🏼", name: "guard: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "💂🏽", name: "guard: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "💂🏾", name: "guard: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "💂🏿", name: "guard: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "💂‍♂️", name: "man guard", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏻‍♂️", name: "man guard: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏼‍♂️", name: "man guard: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏽‍♂️", name: "man guard: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏾‍♂️", name: "man guard: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏿‍♂️", name: "man guard: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂‍♀️", name: "woman guard", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏻‍♀️", name: "woman guard: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏼‍♀️", name: "woman guard: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏽‍♀️", name: "woman guard: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏾‍♀️", name: "woman guard: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💂🏿‍♀️", name: "woman guard: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🥷", name: "ninja", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🥷🏻", name: "ninja: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🥷🏼", name: "ninja: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🥷🏽", name: "ninja: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🥷🏾", name: "ninja: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🥷🏿", name: "ninja: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👷", name: "construction worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👷🏻", name: "construction worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👷🏼", name: "construction worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👷🏽", name: "construction worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👷🏾", name: "construction worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👷🏿", name: "construction worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👷‍♂️", name: "man construction worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏻‍♂️", name: "man construction worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏼‍♂️", name: "man construction worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏽‍♂️", name: "man construction worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏾‍♂️", name: "man construction worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏿‍♂️", name: "man construction worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷‍♀️", name: "woman construction worker", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏻‍♀️", name: "woman construction worker: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏼‍♀️", name: "woman construction worker: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏽‍♀️", name: "woman construction worker: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏾‍♀️", name: "woman construction worker: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👷🏿‍♀️", name: "woman construction worker: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🫅", name: "person with crown", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫅🏻", name: "person with crown: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫅🏼", name: "person with crown: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫅🏽", name: "person with crown: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫅🏾", name: "person with crown: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫅🏿", name: "person with crown: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🤴", name: "prince", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤴🏻", name: "prince: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤴🏼", name: "prince: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤴🏽", name: "prince: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤴🏾", name: "prince: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤴🏿", name: "prince: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👸", name: "princess", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👸🏻", name: "princess: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👸🏼", name: "princess: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👸🏽", name: "princess: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👸🏾", name: "princess: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👸🏿", name: "princess: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👳", name: "person wearing turban", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👳🏻", name: "person wearing turban: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👳🏼", name: "person wearing turban: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👳🏽", name: "person wearing turban: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👳🏾", name: "person wearing turban: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👳🏿", name: "person wearing turban: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👳‍♂️", name: "man wearing turban", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏻‍♂️", name: "man wearing turban: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏼‍♂️", name: "man wearing turban: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏽‍♂️", name: "man wearing turban: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏾‍♂️", name: "man wearing turban: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏿‍♂️", name: "man wearing turban: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳‍♀️", name: "woman wearing turban", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏻‍♀️", name: "woman wearing turban: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏼‍♀️", name: "woman wearing turban: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏽‍♀️", name: "woman wearing turban: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏾‍♀️", name: "woman wearing turban: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👳🏿‍♀️", name: "woman wearing turban: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👲", name: "person with skullcap", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👲🏻", name: "person with skullcap: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👲🏼", name: "person with skullcap: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👲🏽", name: "person with skullcap: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👲🏾", name: "person with skullcap: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👲🏿", name: "person with skullcap: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🧕", name: "woman with headscarf", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🧕🏻", name: "woman with headscarf: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🧕🏼", name: "woman with headscarf: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🧕🏽", name: "woman with headscarf: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🧕🏾", name: "woman with headscarf: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🧕🏿", name: "woman with headscarf: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤵", name: "person in tuxedo", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤵🏻", name: "person in tuxedo: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤵🏼", name: "person in tuxedo: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤵🏽", name: "person in tuxedo: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤵🏾", name: "person in tuxedo: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤵🏿", name: "person in tuxedo: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤵‍♂️", name: "man in tuxedo", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏻‍♂️", name: "man in tuxedo: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏼‍♂️", name: "man in tuxedo: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏽‍♂️", name: "man in tuxedo: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏾‍♂️", name: "man in tuxedo: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏿‍♂️", name: "man in tuxedo: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵‍♀️", name: "woman in tuxedo", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏻‍♀️", name: "woman in tuxedo: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏼‍♀️", name: "woman in tuxedo: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏽‍♀️", name: "woman in tuxedo: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏾‍♀️", name: "woman in tuxedo: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤵🏿‍♀️", name: "woman in tuxedo: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰", name: "person with veil", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👰🏻", name: "person with veil: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👰🏼", name: "person with veil: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👰🏽", name: "person with veil: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👰🏾", name: "person with veil: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👰🏿", name: "person with veil: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👰‍♂️", name: "man with veil", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏻‍♂️", name: "man with veil: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏼‍♂️", name: "man with veil: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏽‍♂️", name: "man with veil: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏾‍♂️", name: "man with veil: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏿‍♂️", name: "man with veil: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰‍♀️", name: "woman with veil", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏻‍♀️", name: "woman with veil: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏼‍♀️", name: "woman with veil: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏽‍♀️", name: "woman with veil: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏾‍♀️", name: "woman with veil: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👰🏿‍♀️", name: "woman with veil: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤰", name: "pregnant woman", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤰🏻", name: "pregnant woman: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤰🏼", name: "pregnant woman: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤰🏽", name: "pregnant woman: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤰🏾", name: "pregnant woman: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤰🏿", name: "pregnant woman: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🫃", name: "pregnant man", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫃🏻", name: "pregnant man: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫃🏼", name: "pregnant man: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫃🏽", name: "pregnant man: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫃🏾", name: "pregnant man: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫃🏿", name: "pregnant man: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫄", name: "pregnant person", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫄🏻", name: "pregnant person: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫄🏼", name: "pregnant person: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫄🏽", name: "pregnant person: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫄🏾", name: "pregnant person: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🫄🏿", name: "pregnant person: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: true, zwjGroup: nil),
    .init(character: "🤱", name: "breast-feeding", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤱🏻", name: "breast-feeding: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤱🏼", name: "breast-feeding: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤱🏽", name: "breast-feeding: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤱🏾", name: "breast-feeding: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "🤱🏿", name: "breast-feeding: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: nil),
    .init(character: "👩‍🍼", name: "woman feeding baby", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🍼", name: "woman feeding baby: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🍼", name: "woman feeding baby: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🍼", name: "woman feeding baby: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🍼", name: "woman feeding baby: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🍼", name: "woman feeding baby: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🍼", name: "man feeding baby", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🍼", name: "man feeding baby: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🍼", name: "man feeding baby: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🍼", name: "man feeding baby: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🍼", name: "man feeding baby: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🍼", name: "man feeding baby: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🍼", name: "person feeding baby", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🍼", name: "person feeding baby: light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🍼", name: "person feeding baby: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🍼", name: "person feeding baby: medium skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🍼", name: "person feeding baby: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🍼", name: "person feeding baby: dark skin tone", category: .init(group: "People & Body", subgroup: "person-role"), isNew: false, zwjGroup: "Role"),
    .init(character: "👼", name: "baby angel", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "👼🏻", name: "baby angel: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "👼🏼", name: "baby angel: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "👼🏽", name: "baby angel: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "👼🏾", name: "baby angel: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "👼🏿", name: "baby angel: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🎅", name: "Santa Claus", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🎅🏻", name: "Santa Claus: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🎅🏼", name: "Santa Claus: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🎅🏽", name: "Santa Claus: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🎅🏾", name: "Santa Claus: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🎅🏿", name: "Santa Claus: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🤶", name: "Mrs. Claus", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🤶🏻", name: "Mrs. Claus: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🤶🏼", name: "Mrs. Claus: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🤶🏽", name: "Mrs. Claus: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🤶🏾", name: "Mrs. Claus: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🤶🏿", name: "Mrs. Claus: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧑‍🎄", name: "mx claus", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Other"),
    .init(character: "🧑🏻‍🎄", name: "mx claus: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍🎄", name: "mx claus: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍🎄", name: "mx claus: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍🎄", name: "mx claus: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍🎄", name: "mx claus: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Family"),
    .init(character: "🦸", name: "superhero", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦸🏻", name: "superhero: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦸🏼", name: "superhero: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦸🏽", name: "superhero: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦸🏾", name: "superhero: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦸🏿", name: "superhero: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦸‍♂️", name: "man superhero", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏻‍♂️", name: "man superhero: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏼‍♂️", name: "man superhero: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏽‍♂️", name: "man superhero: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏾‍♂️", name: "man superhero: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏿‍♂️", name: "man superhero: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸‍♀️", name: "woman superhero", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏻‍♀️", name: "woman superhero: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏼‍♀️", name: "woman superhero: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏽‍♀️", name: "woman superhero: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏾‍♀️", name: "woman superhero: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦸🏿‍♀️", name: "woman superhero: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹", name: "supervillain", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦹🏻", name: "supervillain: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦹🏼", name: "supervillain: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦹🏽", name: "supervillain: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦹🏾", name: "supervillain: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦹🏿", name: "supervillain: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🦹‍♂️", name: "man supervillain", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏻‍♂️", name: "man supervillain: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏼‍♂️", name: "man supervillain: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏽‍♂️", name: "man supervillain: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏾‍♂️", name: "man supervillain: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏿‍♂️", name: "man supervillain: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹‍♀️", name: "woman supervillain", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏻‍♀️", name: "woman supervillain: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏼‍♀️", name: "woman supervillain: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏽‍♀️", name: "woman supervillain: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏾‍♀️", name: "woman supervillain: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🦹🏿‍♀️", name: "woman supervillain: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙", name: "mage", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧙🏻", name: "mage: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧙🏼", name: "mage: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧙🏽", name: "mage: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧙🏾", name: "mage: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧙🏿", name: "mage: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧙‍♂️", name: "man mage", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏻‍♂️", name: "man mage: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏼‍♂️", name: "man mage: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏽‍♂️", name: "man mage: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏾‍♂️", name: "man mage: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏿‍♂️", name: "man mage: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙‍♀️", name: "woman mage", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏻‍♀️", name: "woman mage: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏼‍♀️", name: "woman mage: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏽‍♀️", name: "woman mage: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏾‍♀️", name: "woman mage: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧙🏿‍♀️", name: "woman mage: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚", name: "fairy", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧚🏻", name: "fairy: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧚🏼", name: "fairy: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧚🏽", name: "fairy: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧚🏾", name: "fairy: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧚🏿", name: "fairy: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧚‍♂️", name: "man fairy", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏻‍♂️", name: "man fairy: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏼‍♂️", name: "man fairy: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏽‍♂️", name: "man fairy: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏾‍♂️", name: "man fairy: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏿‍♂️", name: "man fairy: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚‍♀️", name: "woman fairy", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏻‍♀️", name: "woman fairy: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏼‍♀️", name: "woman fairy: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏽‍♀️", name: "woman fairy: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏾‍♀️", name: "woman fairy: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧚🏿‍♀️", name: "woman fairy: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛", name: "vampire", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧛🏻", name: "vampire: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧛🏼", name: "vampire: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧛🏽", name: "vampire: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧛🏾", name: "vampire: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧛🏿", name: "vampire: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧛‍♂️", name: "man vampire", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏻‍♂️", name: "man vampire: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏼‍♂️", name: "man vampire: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏽‍♂️", name: "man vampire: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏾‍♂️", name: "man vampire: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏿‍♂️", name: "man vampire: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛‍♀️", name: "woman vampire", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏻‍♀️", name: "woman vampire: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏼‍♀️", name: "woman vampire: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏽‍♀️", name: "woman vampire: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏾‍♀️", name: "woman vampire: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧛🏿‍♀️", name: "woman vampire: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜", name: "merperson", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧜🏻", name: "merperson: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧜🏼", name: "merperson: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧜🏽", name: "merperson: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧜🏾", name: "merperson: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧜🏿", name: "merperson: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧜‍♂️", name: "merman", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏻‍♂️", name: "merman: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏼‍♂️", name: "merman: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏽‍♂️", name: "merman: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏾‍♂️", name: "merman: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏿‍♂️", name: "merman: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜‍♀️", name: "mermaid", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏻‍♀️", name: "mermaid: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏼‍♀️", name: "mermaid: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏽‍♀️", name: "mermaid: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏾‍♀️", name: "mermaid: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧜🏿‍♀️", name: "mermaid: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝", name: "elf", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧝🏻", name: "elf: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧝🏼", name: "elf: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧝🏽", name: "elf: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧝🏾", name: "elf: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧝🏿", name: "elf: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧝‍♂️", name: "man elf", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏻‍♂️", name: "man elf: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏼‍♂️", name: "man elf: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏽‍♂️", name: "man elf: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏾‍♂️", name: "man elf: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏿‍♂️", name: "man elf: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝‍♀️", name: "woman elf", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏻‍♀️", name: "woman elf: light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏼‍♀️", name: "woman elf: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏽‍♀️", name: "woman elf: medium skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏾‍♀️", name: "woman elf: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧝🏿‍♀️", name: "woman elf: dark skin tone", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧞", name: "genie", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧞‍♂️", name: "man genie", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧞‍♀️", name: "woman genie", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧟", name: "zombie", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: nil),
    .init(character: "🧟‍♂️", name: "man zombie", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧟‍♀️", name: "woman zombie", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧌", name: "troll", category: .init(group: "People & Body", subgroup: "person-fantasy"), isNew: true, zwjGroup: nil),
    .init(character: "💆", name: "person getting massage", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💆🏻", name: "person getting massage: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💆🏼", name: "person getting massage: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💆🏽", name: "person getting massage: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💆🏾", name: "person getting massage: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💆🏿", name: "person getting massage: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💆‍♂️", name: "man getting massage", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏻‍♂️", name: "man getting massage: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏼‍♂️", name: "man getting massage: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏽‍♂️", name: "man getting massage: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏾‍♂️", name: "man getting massage: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏿‍♂️", name: "man getting massage: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆‍♀️", name: "woman getting massage", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏻‍♀️", name: "woman getting massage: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏼‍♀️", name: "woman getting massage: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏽‍♀️", name: "woman getting massage: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏾‍♀️", name: "woman getting massage: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💆🏿‍♀️", name: "woman getting massage: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇", name: "person getting haircut", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💇🏻", name: "person getting haircut: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💇🏼", name: "person getting haircut: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💇🏽", name: "person getting haircut: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💇🏾", name: "person getting haircut: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💇🏿", name: "person getting haircut: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💇‍♂️", name: "man getting haircut", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏻‍♂️", name: "man getting haircut: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏼‍♂️", name: "man getting haircut: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏽‍♂️", name: "man getting haircut: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏾‍♂️", name: "man getting haircut: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏿‍♂️", name: "man getting haircut: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇‍♀️", name: "woman getting haircut", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏻‍♀️", name: "woman getting haircut: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏼‍♀️", name: "woman getting haircut: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏽‍♀️", name: "woman getting haircut: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏾‍♀️", name: "woman getting haircut: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💇🏿‍♀️", name: "woman getting haircut: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶", name: "person walking", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🚶🏻", name: "person walking: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🚶🏼", name: "person walking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🚶🏽", name: "person walking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🚶🏾", name: "person walking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🚶🏿", name: "person walking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🚶‍♂️", name: "man walking", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏻‍♂️", name: "man walking: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏼‍♂️", name: "man walking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏽‍♂️", name: "man walking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏾‍♂️", name: "man walking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏿‍♂️", name: "man walking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶‍♀️", name: "woman walking", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏻‍♀️", name: "woman walking: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏼‍♀️", name: "woman walking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏽‍♀️", name: "woman walking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏾‍♀️", name: "woman walking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚶🏿‍♀️", name: "woman walking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍", name: "person standing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧍🏻", name: "person standing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧍🏼", name: "person standing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧍🏽", name: "person standing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧍🏾", name: "person standing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧍🏿", name: "person standing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧍‍♂️", name: "man standing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏻‍♂️", name: "man standing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏼‍♂️", name: "man standing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏽‍♂️", name: "man standing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏾‍♂️", name: "man standing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏿‍♂️", name: "man standing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍‍♀️", name: "woman standing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏻‍♀️", name: "woman standing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏼‍♀️", name: "woman standing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏽‍♀️", name: "woman standing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏾‍♀️", name: "woman standing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧍🏿‍♀️", name: "woman standing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎", name: "person kneeling", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧎🏻", name: "person kneeling: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧎🏼", name: "person kneeling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧎🏽", name: "person kneeling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧎🏾", name: "person kneeling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧎🏿", name: "person kneeling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧎‍♂️", name: "man kneeling", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏻‍♂️", name: "man kneeling: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏼‍♂️", name: "man kneeling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏽‍♂️", name: "man kneeling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏾‍♂️", name: "man kneeling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏿‍♂️", name: "man kneeling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎‍♀️", name: "woman kneeling", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏻‍♀️", name: "woman kneeling: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏼‍♀️", name: "woman kneeling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏽‍♀️", name: "woman kneeling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏾‍♀️", name: "woman kneeling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧎🏿‍♀️", name: "woman kneeling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧑‍🦯", name: "person with white cane", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🦯", name: "person with white cane: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🦯", name: "person with white cane: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🦯", name: "person with white cane: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🦯", name: "person with white cane: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🦯", name: "person with white cane: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🦯", name: "man with white cane", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🦯", name: "man with white cane: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🦯", name: "man with white cane: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🦯", name: "man with white cane: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🦯", name: "man with white cane: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🦯", name: "man with white cane: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🦯", name: "woman with white cane", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🦯", name: "woman with white cane: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🦯", name: "woman with white cane: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🦯", name: "woman with white cane: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🦯", name: "woman with white cane: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🦯", name: "woman with white cane: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🦼", name: "person in motorized wheelchair", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🦼", name: "person in motorized wheelchair: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🦼", name: "person in motorized wheelchair: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🦼", name: "person in motorized wheelchair: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🦼", name: "person in motorized wheelchair: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🦼", name: "person in motorized wheelchair: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🦼", name: "man in motorized wheelchair", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🦼", name: "man in motorized wheelchair: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🦼", name: "man in motorized wheelchair: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🦼", name: "man in motorized wheelchair: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🦼", name: "man in motorized wheelchair: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🦼", name: "man in motorized wheelchair: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🦼", name: "woman in motorized wheelchair", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🦼", name: "woman in motorized wheelchair: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🦼", name: "woman in motorized wheelchair: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🦼", name: "woman in motorized wheelchair: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🦼", name: "woman in motorized wheelchair: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🦼", name: "woman in motorized wheelchair: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑‍🦽", name: "person in manual wheelchair", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏻‍🦽", name: "person in manual wheelchair: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏼‍🦽", name: "person in manual wheelchair: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏽‍🦽", name: "person in manual wheelchair: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏾‍🦽", name: "person in manual wheelchair: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🧑🏿‍🦽", name: "person in manual wheelchair: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨‍🦽", name: "man in manual wheelchair", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏻‍🦽", name: "man in manual wheelchair: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏼‍🦽", name: "man in manual wheelchair: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏽‍🦽", name: "man in manual wheelchair: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏾‍🦽", name: "man in manual wheelchair: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👨🏿‍🦽", name: "man in manual wheelchair: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩‍🦽", name: "woman in manual wheelchair", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏻‍🦽", name: "woman in manual wheelchair: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏼‍🦽", name: "woman in manual wheelchair: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏽‍🦽", name: "woman in manual wheelchair: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏾‍🦽", name: "woman in manual wheelchair: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "👩🏿‍🦽", name: "woman in manual wheelchair: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Role"),
    .init(character: "🏃", name: "person running", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🏃🏻", name: "person running: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🏃🏼", name: "person running: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🏃🏽", name: "person running: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🏃🏾", name: "person running: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🏃🏿", name: "person running: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🏃‍♂️", name: "man running", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏻‍♂️", name: "man running: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏼‍♂️", name: "man running: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏽‍♂️", name: "man running: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏾‍♂️", name: "man running: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏿‍♂️", name: "man running: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃‍♀️", name: "woman running", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏻‍♀️", name: "woman running: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏼‍♀️", name: "woman running: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏽‍♀️", name: "woman running: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏾‍♀️", name: "woman running: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏃🏿‍♀️", name: "woman running: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "💃", name: "woman dancing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💃🏻", name: "woman dancing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💃🏼", name: "woman dancing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💃🏽", name: "woman dancing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💃🏾", name: "woman dancing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "💃🏿", name: "woman dancing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕺", name: "man dancing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕺🏻", name: "man dancing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕺🏼", name: "man dancing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕺🏽", name: "man dancing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕺🏾", name: "man dancing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕺🏿", name: "man dancing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕴️", name: "person in suit levitating", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕴🏻", name: "person in suit levitating: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕴🏼", name: "person in suit levitating: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕴🏽", name: "person in suit levitating: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕴🏾", name: "person in suit levitating: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🕴🏿", name: "person in suit levitating: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "👯", name: "people with bunny ears", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "👯‍♂️", name: "men with bunny ears", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "👯‍♀️", name: "women with bunny ears", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖", name: "person in steamy room", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧖🏻", name: "person in steamy room: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧖🏼", name: "person in steamy room: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧖🏽", name: "person in steamy room: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧖🏾", name: "person in steamy room: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧖🏿", name: "person in steamy room: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧖‍♂️", name: "man in steamy room", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏻‍♂️", name: "man in steamy room: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏼‍♂️", name: "man in steamy room: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏽‍♂️", name: "man in steamy room: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏾‍♂️", name: "man in steamy room: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏿‍♂️", name: "man in steamy room: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖‍♀️", name: "woman in steamy room", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏻‍♀️", name: "woman in steamy room: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏼‍♀️", name: "woman in steamy room: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏽‍♀️", name: "woman in steamy room: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏾‍♀️", name: "woman in steamy room: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧖🏿‍♀️", name: "woman in steamy room: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗", name: "person climbing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧗🏻", name: "person climbing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧗🏼", name: "person climbing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧗🏽", name: "person climbing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧗🏾", name: "person climbing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧗🏿", name: "person climbing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: nil),
    .init(character: "🧗‍♂️", name: "man climbing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏻‍♂️", name: "man climbing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏼‍♂️", name: "man climbing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏽‍♂️", name: "man climbing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏾‍♂️", name: "man climbing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏿‍♂️", name: "man climbing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗‍♀️", name: "woman climbing", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏻‍♀️", name: "woman climbing: light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏼‍♀️", name: "woman climbing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏽‍♀️", name: "woman climbing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏾‍♀️", name: "woman climbing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧗🏿‍♀️", name: "woman climbing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-activity"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤺", name: "person fencing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏇", name: "horse racing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏇🏻", name: "horse racing: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏇🏼", name: "horse racing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏇🏽", name: "horse racing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏇🏾", name: "horse racing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏇🏿", name: "horse racing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛷️", name: "skier", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏂", name: "snowboarder", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏂🏻", name: "snowboarder: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏂🏼", name: "snowboarder: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏂🏽", name: "snowboarder: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏂🏾", name: "snowboarder: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏂🏿", name: "snowboarder: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏌️", name: "person golfing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏌🏻", name: "person golfing: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏌🏼", name: "person golfing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏌🏽", name: "person golfing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏌🏾", name: "person golfing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏌🏿", name: "person golfing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏌️‍♂️", name: "man golfing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏻‍♂️", name: "man golfing: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏼‍♂️", name: "man golfing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏽‍♂️", name: "man golfing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏾‍♂️", name: "man golfing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏿‍♂️", name: "man golfing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌️‍♀️", name: "woman golfing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏻‍♀️", name: "woman golfing: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏼‍♀️", name: "woman golfing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏽‍♀️", name: "woman golfing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏾‍♀️", name: "woman golfing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏌🏿‍♀️", name: "woman golfing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄", name: "person surfing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏄🏻", name: "person surfing: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏄🏼", name: "person surfing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏄🏽", name: "person surfing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏄🏾", name: "person surfing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏄🏿", name: "person surfing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏄‍♂️", name: "man surfing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏻‍♂️", name: "man surfing: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏼‍♂️", name: "man surfing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏽‍♂️", name: "man surfing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏾‍♂️", name: "man surfing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏿‍♂️", name: "man surfing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄‍♀️", name: "woman surfing", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏻‍♀️", name: "woman surfing: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏼‍♀️", name: "woman surfing: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏽‍♀️", name: "woman surfing: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏾‍♀️", name: "woman surfing: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏄🏿‍♀️", name: "woman surfing: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣", name: "person rowing boat", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚣🏻", name: "person rowing boat: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚣🏼", name: "person rowing boat: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚣🏽", name: "person rowing boat: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚣🏾", name: "person rowing boat: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚣🏿", name: "person rowing boat: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚣‍♂️", name: "man rowing boat", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏻‍♂️", name: "man rowing boat: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏼‍♂️", name: "man rowing boat: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏽‍♂️", name: "man rowing boat: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏾‍♂️", name: "man rowing boat: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏿‍♂️", name: "man rowing boat: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣‍♀️", name: "woman rowing boat", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏻‍♀️", name: "woman rowing boat: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏼‍♀️", name: "woman rowing boat: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏽‍♀️", name: "woman rowing boat: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏾‍♀️", name: "woman rowing boat: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚣🏿‍♀️", name: "woman rowing boat: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊", name: "person swimming", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏊🏻", name: "person swimming: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏊🏼", name: "person swimming: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏊🏽", name: "person swimming: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏊🏾", name: "person swimming: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏊🏿", name: "person swimming: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏊‍♂️", name: "man swimming", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏻‍♂️", name: "man swimming: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏼‍♂️", name: "man swimming: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏽‍♂️", name: "man swimming: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏾‍♂️", name: "man swimming: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏿‍♂️", name: "man swimming: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊‍♀️", name: "woman swimming", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏻‍♀️", name: "woman swimming: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏼‍♀️", name: "woman swimming: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏽‍♀️", name: "woman swimming: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏾‍♀️", name: "woman swimming: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏊🏿‍♀️", name: "woman swimming: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹️", name: "person bouncing ball", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛹🏻", name: "person bouncing ball: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛹🏼", name: "person bouncing ball: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛹🏽", name: "person bouncing ball: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛹🏾", name: "person bouncing ball: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛹🏿", name: "person bouncing ball: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛹️‍♂️", name: "man bouncing ball", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏻‍♂️", name: "man bouncing ball: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏼‍♂️", name: "man bouncing ball: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏽‍♂️", name: "man bouncing ball: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏾‍♂️", name: "man bouncing ball: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏿‍♂️", name: "man bouncing ball: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹️‍♀️", name: "woman bouncing ball", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏻‍♀️", name: "woman bouncing ball: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏼‍♀️", name: "woman bouncing ball: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏽‍♀️", name: "woman bouncing ball: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏾‍♀️", name: "woman bouncing ball: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "⛹🏿‍♀️", name: "woman bouncing ball: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋️", name: "person lifting weights", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏋🏻", name: "person lifting weights: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏋🏼", name: "person lifting weights: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏋🏽", name: "person lifting weights: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏋🏾", name: "person lifting weights: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏋🏿", name: "person lifting weights: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏋️‍♂️", name: "man lifting weights", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏻‍♂️", name: "man lifting weights: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏼‍♂️", name: "man lifting weights: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏽‍♂️", name: "man lifting weights: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏾‍♂️", name: "man lifting weights: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏿‍♂️", name: "man lifting weights: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋️‍♀️", name: "woman lifting weights", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏻‍♀️", name: "woman lifting weights: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏼‍♀️", name: "woman lifting weights: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏽‍♀️", name: "woman lifting weights: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏾‍♀️", name: "woman lifting weights: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🏋🏿‍♀️", name: "woman lifting weights: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴", name: "person biking", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚴🏻", name: "person biking: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚴🏼", name: "person biking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚴🏽", name: "person biking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚴🏾", name: "person biking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚴🏿", name: "person biking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚴‍♂️", name: "man biking", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏻‍♂️", name: "man biking: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏼‍♂️", name: "man biking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏽‍♂️", name: "man biking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏾‍♂️", name: "man biking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏿‍♂️", name: "man biking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴‍♀️", name: "woman biking", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏻‍♀️", name: "woman biking: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏼‍♀️", name: "woman biking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏽‍♀️", name: "woman biking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏾‍♀️", name: "woman biking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚴🏿‍♀️", name: "woman biking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵", name: "person mountain biking", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚵🏻", name: "person mountain biking: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚵🏼", name: "person mountain biking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚵🏽", name: "person mountain biking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚵🏾", name: "person mountain biking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚵🏿", name: "person mountain biking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🚵‍♂️", name: "man mountain biking", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏻‍♂️", name: "man mountain biking: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏼‍♂️", name: "man mountain biking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏽‍♂️", name: "man mountain biking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏾‍♂️", name: "man mountain biking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏿‍♂️", name: "man mountain biking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵‍♀️", name: "woman mountain biking", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏻‍♀️", name: "woman mountain biking: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏼‍♀️", name: "woman mountain biking: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏽‍♀️", name: "woman mountain biking: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏾‍♀️", name: "woman mountain biking: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🚵🏿‍♀️", name: "woman mountain biking: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸", name: "person cartwheeling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤸🏻", name: "person cartwheeling: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤸🏼", name: "person cartwheeling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤸🏽", name: "person cartwheeling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤸🏾", name: "person cartwheeling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤸🏿", name: "person cartwheeling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤸‍♂️", name: "man cartwheeling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏻‍♂️", name: "man cartwheeling: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏼‍♂️", name: "man cartwheeling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏽‍♂️", name: "man cartwheeling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏾‍♂️", name: "man cartwheeling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏿‍♂️", name: "man cartwheeling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸‍♀️", name: "woman cartwheeling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏻‍♀️", name: "woman cartwheeling: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏼‍♀️", name: "woman cartwheeling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏽‍♀️", name: "woman cartwheeling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏾‍♀️", name: "woman cartwheeling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤸🏿‍♀️", name: "woman cartwheeling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤼", name: "people wrestling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤼‍♂️", name: "men wrestling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤼‍♀️", name: "women wrestling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽", name: "person playing water polo", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤽🏻", name: "person playing water polo: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤽🏼", name: "person playing water polo: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤽🏽", name: "person playing water polo: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤽🏾", name: "person playing water polo: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤽🏿", name: "person playing water polo: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤽‍♂️", name: "man playing water polo", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏻‍♂️", name: "man playing water polo: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏼‍♂️", name: "man playing water polo: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏽‍♂️", name: "man playing water polo: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏾‍♂️", name: "man playing water polo: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏿‍♂️", name: "man playing water polo: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽‍♀️", name: "woman playing water polo", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏻‍♀️", name: "woman playing water polo: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏼‍♀️", name: "woman playing water polo: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏽‍♀️", name: "woman playing water polo: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏾‍♀️", name: "woman playing water polo: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤽🏿‍♀️", name: "woman playing water polo: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾", name: "person playing handball", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤾🏻", name: "person playing handball: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤾🏼", name: "person playing handball: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤾🏽", name: "person playing handball: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤾🏾", name: "person playing handball: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤾🏿", name: "person playing handball: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤾‍♂️", name: "man playing handball", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏻‍♂️", name: "man playing handball: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏼‍♂️", name: "man playing handball: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏽‍♂️", name: "man playing handball: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏾‍♂️", name: "man playing handball: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏿‍♂️", name: "man playing handball: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾‍♀️", name: "woman playing handball", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏻‍♀️", name: "woman playing handball: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏼‍♀️", name: "woman playing handball: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏽‍♀️", name: "woman playing handball: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏾‍♀️", name: "woman playing handball: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤾🏿‍♀️", name: "woman playing handball: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹", name: "person juggling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤹🏻", name: "person juggling: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤹🏼", name: "person juggling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤹🏽", name: "person juggling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤹🏾", name: "person juggling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤹🏿", name: "person juggling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤹‍♂️", name: "man juggling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏻‍♂️", name: "man juggling: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏼‍♂️", name: "man juggling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏽‍♂️", name: "man juggling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏾‍♂️", name: "man juggling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏿‍♂️", name: "man juggling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹‍♀️", name: "woman juggling", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏻‍♀️", name: "woman juggling: light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏼‍♀️", name: "woman juggling: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏽‍♀️", name: "woman juggling: medium skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏾‍♀️", name: "woman juggling: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🤹🏿‍♀️", name: "woman juggling: dark skin tone", category: .init(group: "People & Body", subgroup: "person-sport"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘", name: "person in lotus position", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🧘🏻", name: "person in lotus position: light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🧘🏼", name: "person in lotus position: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🧘🏽", name: "person in lotus position: medium skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🧘🏾", name: "person in lotus position: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🧘🏿", name: "person in lotus position: dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🧘‍♂️", name: "man in lotus position", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏻‍♂️", name: "man in lotus position: light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏼‍♂️", name: "man in lotus position: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏽‍♂️", name: "man in lotus position: medium skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏾‍♂️", name: "man in lotus position: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏿‍♂️", name: "man in lotus position: dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘‍♀️", name: "woman in lotus position", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏻‍♀️", name: "woman in lotus position: light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏼‍♀️", name: "woman in lotus position: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏽‍♀️", name: "woman in lotus position: medium skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏾‍♀️", name: "woman in lotus position: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🧘🏿‍♀️", name: "woman in lotus position: dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: "Gendered"),
    .init(character: "🛀", name: "person taking bath", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛀🏻", name: "person taking bath: light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛀🏼", name: "person taking bath: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛀🏽", name: "person taking bath: medium skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛀🏾", name: "person taking bath: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛀🏿", name: "person taking bath: dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛌", name: "person in bed", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛌🏻", name: "person in bed: light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛌🏼", name: "person in bed: medium-light skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛌🏽", name: "person in bed: medium skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛌🏾", name: "person in bed: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🛌🏿", name: "person in bed: dark skin tone", category: .init(group: "People & Body", subgroup: "person-resting"), isNew: false, zwjGroup: nil),
    .init(character: "🧑‍🤝‍🧑", name: "people holding hands", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍🤝‍🧑🏻", name: "people holding hands: light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍🤝‍🧑🏼", name: "people holding hands: light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍🤝‍🧑🏽", name: "people holding hands: light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍🤝‍🧑🏾", name: "people holding hands: light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍🤝‍🧑🏿", name: "people holding hands: light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍🤝‍🧑🏻", name: "people holding hands: medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍🤝‍🧑🏼", name: "people holding hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍🤝‍🧑🏽", name: "people holding hands: medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍🤝‍🧑🏾", name: "people holding hands: medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍🤝‍🧑🏿", name: "people holding hands: medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍🤝‍🧑🏻", name: "people holding hands: medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍🤝‍🧑🏼", name: "people holding hands: medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍🤝‍🧑🏽", name: "people holding hands: medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍🤝‍🧑🏾", name: "people holding hands: medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍🤝‍🧑🏿", name: "people holding hands: medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍🤝‍🧑🏻", name: "people holding hands: medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍🤝‍🧑🏼", name: "people holding hands: medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍🤝‍🧑🏽", name: "people holding hands: medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍🤝‍🧑🏾", name: "people holding hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍🤝‍🧑🏿", name: "people holding hands: medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍🤝‍🧑🏻", name: "people holding hands: dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍🤝‍🧑🏼", name: "people holding hands: dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍🤝‍🧑🏽", name: "people holding hands: dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍🤝‍🧑🏾", name: "people holding hands: dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍🤝‍🧑🏿", name: "people holding hands: dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👭", name: "women holding hands", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👭🏻", name: "women holding hands: light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏻‍🤝‍👩🏼", name: "women holding hands: light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍🤝‍👩🏽", name: "women holding hands: light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍🤝‍👩🏾", name: "women holding hands: light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍🤝‍👩🏿", name: "women holding hands: light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍🤝‍👩🏻", name: "women holding hands: medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👭🏼", name: "women holding hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏼‍🤝‍👩🏽", name: "women holding hands: medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍🤝‍👩🏾", name: "women holding hands: medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍🤝‍👩🏿", name: "women holding hands: medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍🤝‍👩🏻", name: "women holding hands: medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍🤝‍👩🏼", name: "women holding hands: medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👭🏽", name: "women holding hands: medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏽‍🤝‍👩🏾", name: "women holding hands: medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍🤝‍👩🏿", name: "women holding hands: medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍🤝‍👩🏻", name: "women holding hands: medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍🤝‍👩🏼", name: "women holding hands: medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍🤝‍👩🏽", name: "women holding hands: medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👭🏾", name: "women holding hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏾‍🤝‍👩🏿", name: "women holding hands: medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👩🏻", name: "women holding hands: dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👩🏼", name: "women holding hands: dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👩🏽", name: "women holding hands: dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👩🏾", name: "women holding hands: dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👭🏿", name: "women holding hands: dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👫", name: "woman and man holding hands", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👫🏻", name: "woman and man holding hands: light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏻‍🤝‍👨🏼", name: "woman and man holding hands: light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍🤝‍👨🏽", name: "woman and man holding hands: light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍🤝‍👨🏾", name: "woman and man holding hands: light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍🤝‍👨🏿", name: "woman and man holding hands: light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍🤝‍👨🏻", name: "woman and man holding hands: medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👫🏼", name: "woman and man holding hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏼‍🤝‍👨🏽", name: "woman and man holding hands: medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍🤝‍👨🏾", name: "woman and man holding hands: medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍🤝‍👨🏿", name: "woman and man holding hands: medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍🤝‍👨🏻", name: "woman and man holding hands: medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍🤝‍👨🏼", name: "woman and man holding hands: medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👫🏽", name: "woman and man holding hands: medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏽‍🤝‍👨🏾", name: "woman and man holding hands: medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍🤝‍👨🏿", name: "woman and man holding hands: medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍🤝‍👨🏻", name: "woman and man holding hands: medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍🤝‍👨🏼", name: "woman and man holding hands: medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍🤝‍👨🏽", name: "woman and man holding hands: medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👫🏾", name: "woman and man holding hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👩🏾‍🤝‍👨🏿", name: "woman and man holding hands: medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👨🏻", name: "woman and man holding hands: dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👨🏼", name: "woman and man holding hands: dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👨🏽", name: "woman and man holding hands: dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍🤝‍👨🏾", name: "woman and man holding hands: dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👫🏿", name: "woman and man holding hands: dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👬", name: "men holding hands", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👬🏻", name: "men holding hands: light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏻‍🤝‍👨🏼", name: "men holding hands: light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍🤝‍👨🏽", name: "men holding hands: light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍🤝‍👨🏾", name: "men holding hands: light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍🤝‍👨🏿", name: "men holding hands: light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍🤝‍👨🏻", name: "men holding hands: medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👬🏼", name: "men holding hands: medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏼‍🤝‍👨🏽", name: "men holding hands: medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍🤝‍👨🏾", name: "men holding hands: medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍🤝‍👨🏿", name: "men holding hands: medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍🤝‍👨🏻", name: "men holding hands: medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍🤝‍👨🏼", name: "men holding hands: medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👬🏽", name: "men holding hands: medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏽‍🤝‍👨🏾", name: "men holding hands: medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍🤝‍👨🏿", name: "men holding hands: medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍🤝‍👨🏻", name: "men holding hands: medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍🤝‍👨🏼", name: "men holding hands: medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍🤝‍👨🏽", name: "men holding hands: medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👬🏾", name: "men holding hands: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👨🏾‍🤝‍👨🏿", name: "men holding hands: medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍🤝‍👨🏻", name: "men holding hands: dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍🤝‍👨🏼", name: "men holding hands: dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍🤝‍👨🏽", name: "men holding hands: dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍🤝‍👨🏾", name: "men holding hands: dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👬🏿", name: "men holding hands: dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💏", name: "kiss", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💏🏻", name: "kiss: light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💏🏼", name: "kiss: medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💏🏽", name: "kiss: medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💏🏾", name: "kiss: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💏🏿", name: "kiss: dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "🧑🏻‍❤️‍💋‍🧑🏼", name: "kiss: person, person, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍❤️‍💋‍🧑🏽", name: "kiss: person, person, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍❤️‍💋‍🧑🏾", name: "kiss: person, person, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍❤️‍💋‍🧑🏿", name: "kiss: person, person, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍💋‍🧑🏻", name: "kiss: person, person, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍💋‍🧑🏽", name: "kiss: person, person, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍💋‍🧑🏾", name: "kiss: person, person, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍💋‍🧑🏿", name: "kiss: person, person, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍💋‍🧑🏻", name: "kiss: person, person, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍💋‍🧑🏼", name: "kiss: person, person, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍💋‍🧑🏾", name: "kiss: person, person, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍💋‍🧑🏿", name: "kiss: person, person, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍💋‍🧑🏻", name: "kiss: person, person, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍💋‍🧑🏼", name: "kiss: person, person, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍💋‍🧑🏽", name: "kiss: person, person, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍💋‍🧑🏿", name: "kiss: person, person, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍💋‍🧑🏻", name: "kiss: person, person, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍💋‍🧑🏼", name: "kiss: person, person, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍💋‍🧑🏽", name: "kiss: person, person, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍💋‍🧑🏾", name: "kiss: person, person, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍❤️‍💋‍👨", name: "kiss: woman, man", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👨🏻", name: "kiss: woman, man, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👨🏼", name: "kiss: woman, man, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👨🏽", name: "kiss: woman, man, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👨🏾", name: "kiss: woman, man, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👨🏿", name: "kiss: woman, man, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👨🏻", name: "kiss: woman, man, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👨🏼", name: "kiss: woman, man, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👨🏽", name: "kiss: woman, man, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👨🏾", name: "kiss: woman, man, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👨🏿", name: "kiss: woman, man, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👨🏻", name: "kiss: woman, man, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👨🏼", name: "kiss: woman, man, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👨🏽", name: "kiss: woman, man, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👨🏾", name: "kiss: woman, man, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👨🏿", name: "kiss: woman, man, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👨🏻", name: "kiss: woman, man, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👨🏼", name: "kiss: woman, man, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👨🏽", name: "kiss: woman, man, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👨🏾", name: "kiss: woman, man, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👨🏿", name: "kiss: woman, man, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👨🏻", name: "kiss: woman, man, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👨🏼", name: "kiss: woman, man, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👨🏽", name: "kiss: woman, man, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👨🏾", name: "kiss: woman, man, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👨🏿", name: "kiss: woman, man, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍❤️‍💋‍👨", name: "kiss: man, man", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍💋‍👨🏻", name: "kiss: man, man, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍💋‍👨🏼", name: "kiss: man, man, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍💋‍👨🏽", name: "kiss: man, man, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍💋‍👨🏾", name: "kiss: man, man, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍💋‍👨🏿", name: "kiss: man, man, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍💋‍👨🏻", name: "kiss: man, man, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍💋‍👨🏼", name: "kiss: man, man, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍💋‍👨🏽", name: "kiss: man, man, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍💋‍👨🏾", name: "kiss: man, man, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍💋‍👨🏿", name: "kiss: man, man, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍💋‍👨🏻", name: "kiss: man, man, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍💋‍👨🏼", name: "kiss: man, man, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍💋‍👨🏽", name: "kiss: man, man, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍💋‍👨🏾", name: "kiss: man, man, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍💋‍👨🏿", name: "kiss: man, man, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍💋‍👨🏻", name: "kiss: man, man, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍💋‍👨🏼", name: "kiss: man, man, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍💋‍👨🏽", name: "kiss: man, man, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍💋‍👨🏾", name: "kiss: man, man, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍💋‍👨🏿", name: "kiss: man, man, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍💋‍👨🏻", name: "kiss: man, man, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍💋‍👨🏼", name: "kiss: man, man, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍💋‍👨🏽", name: "kiss: man, man, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍💋‍👨🏾", name: "kiss: man, man, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍💋‍👨🏿", name: "kiss: man, man, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍❤️‍💋‍👩", name: "kiss: woman, woman", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👩🏻", name: "kiss: woman, woman, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👩🏼", name: "kiss: woman, woman, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👩🏽", name: "kiss: woman, woman, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👩🏾", name: "kiss: woman, woman, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍💋‍👩🏿", name: "kiss: woman, woman, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👩🏻", name: "kiss: woman, woman, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👩🏼", name: "kiss: woman, woman, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👩🏽", name: "kiss: woman, woman, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👩🏾", name: "kiss: woman, woman, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍💋‍👩🏿", name: "kiss: woman, woman, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👩🏻", name: "kiss: woman, woman, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👩🏼", name: "kiss: woman, woman, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👩🏽", name: "kiss: woman, woman, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👩🏾", name: "kiss: woman, woman, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍💋‍👩🏿", name: "kiss: woman, woman, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👩🏻", name: "kiss: woman, woman, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👩🏼", name: "kiss: woman, woman, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👩🏽", name: "kiss: woman, woman, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👩🏾", name: "kiss: woman, woman, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍💋‍👩🏿", name: "kiss: woman, woman, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👩🏻", name: "kiss: woman, woman, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👩🏼", name: "kiss: woman, woman, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👩🏽", name: "kiss: woman, woman, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👩🏾", name: "kiss: woman, woman, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍💋‍👩🏿", name: "kiss: woman, woman, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "💑", name: "couple with heart", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💑🏻", name: "couple with heart: light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💑🏼", name: "couple with heart: medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💑🏽", name: "couple with heart: medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💑🏾", name: "couple with heart: medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "💑🏿", name: "couple with heart: dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "🧑🏻‍❤️‍🧑🏼", name: "couple with heart: person, person, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍❤️‍🧑🏽", name: "couple with heart: person, person, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍❤️‍🧑🏾", name: "couple with heart: person, person, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏻‍❤️‍🧑🏿", name: "couple with heart: person, person, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍🧑🏻", name: "couple with heart: person, person, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍🧑🏽", name: "couple with heart: person, person, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍🧑🏾", name: "couple with heart: person, person, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏼‍❤️‍🧑🏿", name: "couple with heart: person, person, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍🧑🏻", name: "couple with heart: person, person, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍🧑🏼", name: "couple with heart: person, person, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍🧑🏾", name: "couple with heart: person, person, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏽‍❤️‍🧑🏿", name: "couple with heart: person, person, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍🧑🏻", name: "couple with heart: person, person, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍🧑🏼", name: "couple with heart: person, person, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍🧑🏽", name: "couple with heart: person, person, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏾‍❤️‍🧑🏿", name: "couple with heart: person, person, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍🧑🏻", name: "couple with heart: person, person, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍🧑🏼", name: "couple with heart: person, person, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍🧑🏽", name: "couple with heart: person, person, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🧑🏿‍❤️‍🧑🏾", name: "couple with heart: person, person, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍❤️‍👨", name: "couple with heart: woman, man", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👨🏻", name: "couple with heart: woman, man, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👨🏼", name: "couple with heart: woman, man, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👨🏽", name: "couple with heart: woman, man, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👨🏾", name: "couple with heart: woman, man, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👨🏿", name: "couple with heart: woman, man, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👨🏻", name: "couple with heart: woman, man, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👨🏼", name: "couple with heart: woman, man, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👨🏽", name: "couple with heart: woman, man, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👨🏾", name: "couple with heart: woman, man, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👨🏿", name: "couple with heart: woman, man, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👨🏻", name: "couple with heart: woman, man, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👨🏼", name: "couple with heart: woman, man, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👨🏽", name: "couple with heart: woman, man, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👨🏾", name: "couple with heart: woman, man, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👨🏿", name: "couple with heart: woman, man, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👨🏻", name: "couple with heart: woman, man, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👨🏼", name: "couple with heart: woman, man, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👨🏽", name: "couple with heart: woman, man, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👨🏾", name: "couple with heart: woman, man, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👨🏿", name: "couple with heart: woman, man, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👨🏻", name: "couple with heart: woman, man, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👨🏼", name: "couple with heart: woman, man, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👨🏽", name: "couple with heart: woman, man, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👨🏾", name: "couple with heart: woman, man, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👨🏿", name: "couple with heart: woman, man, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍❤️‍👨", name: "couple with heart: man, man", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍👨🏻", name: "couple with heart: man, man, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍👨🏼", name: "couple with heart: man, man, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍👨🏽", name: "couple with heart: man, man, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍👨🏾", name: "couple with heart: man, man, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏻‍❤️‍👨🏿", name: "couple with heart: man, man, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍👨🏻", name: "couple with heart: man, man, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍👨🏼", name: "couple with heart: man, man, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍👨🏽", name: "couple with heart: man, man, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍👨🏾", name: "couple with heart: man, man, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏼‍❤️‍👨🏿", name: "couple with heart: man, man, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍👨🏻", name: "couple with heart: man, man, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍👨🏼", name: "couple with heart: man, man, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍👨🏽", name: "couple with heart: man, man, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍👨🏾", name: "couple with heart: man, man, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏽‍❤️‍👨🏿", name: "couple with heart: man, man, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍👨🏻", name: "couple with heart: man, man, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍👨🏼", name: "couple with heart: man, man, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍👨🏽", name: "couple with heart: man, man, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍👨🏾", name: "couple with heart: man, man, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏾‍❤️‍👨🏿", name: "couple with heart: man, man, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍👨🏻", name: "couple with heart: man, man, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍👨🏼", name: "couple with heart: man, man, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍👨🏽", name: "couple with heart: man, man, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍👨🏾", name: "couple with heart: man, man, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨🏿‍❤️‍👨🏿", name: "couple with heart: man, man, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍❤️‍👩", name: "couple with heart: woman, woman", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👩🏻", name: "couple with heart: woman, woman, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👩🏼", name: "couple with heart: woman, woman, light skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👩🏽", name: "couple with heart: woman, woman, light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👩🏾", name: "couple with heart: woman, woman, light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏻‍❤️‍👩🏿", name: "couple with heart: woman, woman, light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👩🏻", name: "couple with heart: woman, woman, medium-light skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👩🏼", name: "couple with heart: woman, woman, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👩🏽", name: "couple with heart: woman, woman, medium-light skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👩🏾", name: "couple with heart: woman, woman, medium-light skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏼‍❤️‍👩🏿", name: "couple with heart: woman, woman, medium-light skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👩🏻", name: "couple with heart: woman, woman, medium skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👩🏼", name: "couple with heart: woman, woman, medium skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👩🏽", name: "couple with heart: woman, woman, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👩🏾", name: "couple with heart: woman, woman, medium skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏽‍❤️‍👩🏿", name: "couple with heart: woman, woman, medium skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👩🏻", name: "couple with heart: woman, woman, medium-dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👩🏼", name: "couple with heart: woman, woman, medium-dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👩🏽", name: "couple with heart: woman, woman, medium-dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👩🏾", name: "couple with heart: woman, woman, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏾‍❤️‍👩🏿", name: "couple with heart: woman, woman, medium-dark skin tone, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👩🏻", name: "couple with heart: woman, woman, dark skin tone, light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👩🏼", name: "couple with heart: woman, woman, dark skin tone, medium-light skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👩🏽", name: "couple with heart: woman, woman, dark skin tone, medium skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👩🏾", name: "couple with heart: woman, woman, dark skin tone, medium-dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩🏿‍❤️‍👩🏿", name: "couple with heart: woman, woman, dark skin tone", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👪", name: "family", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: nil),
    .init(character: "👨‍👩‍👦", name: "family: man, woman, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👩‍👧", name: "family: man, woman, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👩‍👧‍👦", name: "family: man, woman, girl, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👩‍👦‍👦", name: "family: man, woman, boy, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👩‍👧‍👧", name: "family: man, woman, girl, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👨‍👦", name: "family: man, man, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👨‍👧", name: "family: man, man, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👨‍👧‍👦", name: "family: man, man, girl, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👨‍👦‍👦", name: "family: man, man, boy, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👨‍👧‍👧", name: "family: man, man, girl, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👩‍👦", name: "family: woman, woman, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👩‍👧", name: "family: woman, woman, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👩‍👧‍👦", name: "family: woman, woman, girl, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👩‍👦‍👦", name: "family: woman, woman, boy, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👩‍👧‍👧", name: "family: woman, woman, girl, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👦", name: "family: man, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👦‍👦", name: "family: man, boy, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👧", name: "family: man, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👧‍👦", name: "family: man, girl, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👨‍👧‍👧", name: "family: man, girl, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👦", name: "family: woman, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👦‍👦", name: "family: woman, boy, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👧", name: "family: woman, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👧‍👦", name: "family: woman, girl, boy", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "👩‍👧‍👧", name: "family: woman, girl, girl", category: .init(group: "People & Body", subgroup: "family"), isNew: false, zwjGroup: "Family"),
    .init(character: "🗣️", name: "speaking head", category: .init(group: "People & Body", subgroup: "person-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "👤", name: "bust in silhouette", category: .init(group: "People & Body", subgroup: "person-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "👥", name: "busts in silhouette", category: .init(group: "People & Body", subgroup: "person-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🫂", name: "people hugging", category: .init(group: "People & Body", subgroup: "person-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "👣", name: "footprints", category: .init(group: "People & Body", subgroup: "person-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🐵", name: "monkey face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐒", name: "monkey", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦍", name: "gorilla", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦧", name: "orangutan", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐶", name: "dog face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐕", name: "dog", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦮", name: "guide dog", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐕‍🦺", name: "service dog", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: "Other"),
    .init(character: "🐩", name: "poodle", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐺", name: "wolf", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦊", name: "fox", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦝", name: "raccoon", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐱", name: "cat face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐈", name: "cat", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐈‍⬛", name: "black cat", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: "Other"),
    .init(character: "🦁", name: "lion", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐯", name: "tiger face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐅", name: "tiger", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐆", name: "leopard", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐴", name: "horse face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐎", name: "horse", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦄", name: "unicorn", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦓", name: "zebra", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦌", name: "deer", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦬", name: "bison", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐮", name: "cow face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐂", name: "ox", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐃", name: "water buffalo", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐄", name: "cow", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐷", name: "pig face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐖", name: "pig", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐗", name: "boar", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐽", name: "pig nose", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐏", name: "ram", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐑", name: "ewe", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐐", name: "goat", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐪", name: "camel", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐫", name: "two-hump camel", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦙", name: "llama", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦒", name: "giraffe", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐘", name: "elephant", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦣", name: "mammoth", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦏", name: "rhinoceros", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦛", name: "hippopotamus", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐭", name: "mouse face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐁", name: "mouse", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐀", name: "rat", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐹", name: "hamster", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐰", name: "rabbit face", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐇", name: "rabbit", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐿️", name: "chipmunk", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦫", name: "beaver", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦔", name: "hedgehog", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦇", name: "bat", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐻", name: "bear", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐻‍❄️", name: "polar bear", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: "Other"),
    .init(character: "🐨", name: "koala", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐼", name: "panda", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦥", name: "sloth", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦦", name: "otter", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦨", name: "skunk", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦘", name: "kangaroo", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦡", name: "badger", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🐾", name: "paw prints", category: .init(group: "Animals & Nature", subgroup: "animal-mammal"), isNew: false, zwjGroup: nil),
    .init(character: "🦃", name: "turkey", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐔", name: "chicken", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐓", name: "rooster", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐣", name: "hatching chick", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐤", name: "baby chick", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐥", name: "front-facing baby chick", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐦", name: "bird", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐧", name: "penguin", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🕊️", name: "dove", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦅", name: "eagle", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦆", name: "duck", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦢", name: "swan", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦉", name: "owl", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦤", name: "dodo", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🪶", name: "feather", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦩", name: "flamingo", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦚", name: "peacock", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🦜", name: "parrot", category: .init(group: "Animals & Nature", subgroup: "animal-bird"), isNew: false, zwjGroup: nil),
    .init(character: "🐸", name: "frog", category: .init(group: "Animals & Nature", subgroup: "animal-amphibian"), isNew: false, zwjGroup: nil),
    .init(character: "🐊", name: "crocodile", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🐢", name: "turtle", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🦎", name: "lizard", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🐍", name: "snake", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🐲", name: "dragon face", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🐉", name: "dragon", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🦕", name: "sauropod", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🦖", name: "T-Rex", category: .init(group: "Animals & Nature", subgroup: "animal-reptile"), isNew: false, zwjGroup: nil),
    .init(character: "🐳", name: "spouting whale", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🐋", name: "whale", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🐬", name: "dolphin", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🦭", name: "seal", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🐟", name: "fish", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🐠", name: "tropical fish", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🐡", name: "blowfish", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🦈", name: "shark", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🐙", name: "octopus", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🐚", name: "spiral shell", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🪸", name: "coral", category: .init(group: "Animals & Nature", subgroup: "animal-marine"), isNew: true, zwjGroup: nil),
    .init(character: "🐌", name: "snail", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🦋", name: "butterfly", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🐛", name: "bug", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🐜", name: "ant", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🐝", name: "honeybee", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🪲", name: "beetle", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🐞", name: "lady beetle", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🦗", name: "cricket", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🪳", name: "cockroach", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🕷️", name: "spider", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🕸️", name: "spider web", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🦂", name: "scorpion", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🦟", name: "mosquito", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🪰", name: "fly", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🪱", name: "worm", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "🦠", name: "microbe", category: .init(group: "Animals & Nature", subgroup: "animal-bug"), isNew: false, zwjGroup: nil),
    .init(character: "💐", name: "bouquet", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🌸", name: "cherry blossom", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "💮", name: "white flower", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🪷", name: "lotus", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: true, zwjGroup: nil),
    .init(character: "🏵️", name: "rosette", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🌹", name: "rose", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🥀", name: "wilted flower", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🌺", name: "hibiscus", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🌻", name: "sunflower", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🌼", name: "blossom", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🌷", name: "tulip", category: .init(group: "Animals & Nature", subgroup: "plant-flower"), isNew: false, zwjGroup: nil),
    .init(character: "🌱", name: "seedling", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🪴", name: "potted plant", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌲", name: "evergreen tree", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌳", name: "deciduous tree", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌴", name: "palm tree", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌵", name: "cactus", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌾", name: "sheaf of rice", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌿", name: "herb", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "☘️", name: "shamrock", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🍀", name: "four leaf clover", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🍁", name: "maple leaf", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🍂", name: "fallen leaf", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🍃", name: "leaf fluttering in wind", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: false, zwjGroup: nil),
    .init(character: "🪹", name: "empty nest", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: true, zwjGroup: nil),
    .init(character: "🪺", name: "nest with eggs", category: .init(group: "Animals & Nature", subgroup: "plant-other"), isNew: true, zwjGroup: nil),
    .init(character: "🍇", name: "grapes", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍈", name: "melon", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍉", name: "watermelon", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍊", name: "tangerine", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍋", name: "lemon", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍌", name: "banana", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍍", name: "pineapple", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🥭", name: "mango", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍎", name: "red apple", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍏", name: "green apple", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍐", name: "pear", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍑", name: "peach", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍒", name: "cherries", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍓", name: "strawberry", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🫐", name: "blueberries", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🥝", name: "kiwi fruit", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🍅", name: "tomato", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🫒", name: "olive", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🥥", name: "coconut", category: .init(group: "Food & Drink", subgroup: "food-fruit"), isNew: false, zwjGroup: nil),
    .init(character: "🥑", name: "avocado", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🍆", name: "eggplant", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🥔", name: "potato", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🥕", name: "carrot", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🌽", name: "ear of corn", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🌶️", name: "hot pepper", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🫑", name: "bell pepper", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🥒", name: "cucumber", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🥬", name: "leafy green", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🥦", name: "broccoli", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🧄", name: "garlic", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🧅", name: "onion", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🍄", name: "mushroom", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🥜", name: "peanuts", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🫘", name: "beans", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: true, zwjGroup: nil),
    .init(character: "🌰", name: "chestnut", category: .init(group: "Food & Drink", subgroup: "food-vegetable"), isNew: false, zwjGroup: nil),
    .init(character: "🍞", name: "bread", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥐", name: "croissant", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥖", name: "baguette bread", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🫓", name: "flatbread", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥨", name: "pretzel", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥯", name: "bagel", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥞", name: "pancakes", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🧇", name: "waffle", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🧀", name: "cheese wedge", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍖", name: "meat on bone", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍗", name: "poultry leg", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥩", name: "cut of meat", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥓", name: "bacon", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍔", name: "hamburger", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍟", name: "french fries", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍕", name: "pizza", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🌭", name: "hot dog", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥪", name: "sandwich", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🌮", name: "taco", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🌯", name: "burrito", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🫔", name: "tamale", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥙", name: "stuffed flatbread", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🧆", name: "falafel", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥚", name: "egg", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍳", name: "cooking", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥘", name: "shallow pan of food", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍲", name: "pot of food", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🫕", name: "fondue", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥣", name: "bowl with spoon", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥗", name: "green salad", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍿", name: "popcorn", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🧈", name: "butter", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🧂", name: "salt", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🥫", name: "canned food", category: .init(group: "Food & Drink", subgroup: "food-prepared"), isNew: false, zwjGroup: nil),
    .init(character: "🍱", name: "bento box", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍘", name: "rice cracker", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍙", name: "rice ball", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍚", name: "cooked rice", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍛", name: "curry rice", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍜", name: "steaming bowl", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍝", name: "spaghetti", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍠", name: "roasted sweet potato", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍢", name: "oden", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍣", name: "sushi", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍤", name: "fried shrimp", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍥", name: "fish cake with swirl", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🥮", name: "moon cake", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🍡", name: "dango", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🥟", name: "dumpling", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🥠", name: "fortune cookie", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🥡", name: "takeout box", category: .init(group: "Food & Drink", subgroup: "food-asian"), isNew: false, zwjGroup: nil),
    .init(character: "🦀", name: "crab", category: .init(group: "Food & Drink", subgroup: "food-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🦞", name: "lobster", category: .init(group: "Food & Drink", subgroup: "food-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🦐", name: "shrimp", category: .init(group: "Food & Drink", subgroup: "food-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🦑", name: "squid", category: .init(group: "Food & Drink", subgroup: "food-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🦪", name: "oyster", category: .init(group: "Food & Drink", subgroup: "food-marine"), isNew: false, zwjGroup: nil),
    .init(character: "🍦", name: "soft ice cream", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍧", name: "shaved ice", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍨", name: "ice cream", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍩", name: "doughnut", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍪", name: "cookie", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🎂", name: "birthday cake", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍰", name: "shortcake", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🧁", name: "cupcake", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🥧", name: "pie", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍫", name: "chocolate bar", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍬", name: "candy", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍭", name: "lollipop", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍮", name: "custard", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍯", name: "honey pot", category: .init(group: "Food & Drink", subgroup: "food-sweet"), isNew: false, zwjGroup: nil),
    .init(character: "🍼", name: "baby bottle", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🥛", name: "glass of milk", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "☕", name: "hot beverage", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🫖", name: "teapot", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍵", name: "teacup without handle", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍶", name: "sake", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍾", name: "bottle with popping cork", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍷", name: "wine glass", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍸", name: "cocktail glass", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍹", name: "tropical drink", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍺", name: "beer mug", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🍻", name: "clinking beer mugs", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🥂", name: "clinking glasses", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🥃", name: "tumbler glass", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🫗", name: "pouring liquid", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: true, zwjGroup: nil),
    .init(character: "🥤", name: "cup with straw", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🧋", name: "bubble tea", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🧃", name: "beverage box", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🧉", name: "mate", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🧊", name: "ice", category: .init(group: "Food & Drink", subgroup: "drink"), isNew: false, zwjGroup: nil),
    .init(character: "🥢", name: "chopsticks", category: .init(group: "Food & Drink", subgroup: "dishware"), isNew: false, zwjGroup: nil),
    .init(character: "🍽️", name: "fork and knife with plate", category: .init(group: "Food & Drink", subgroup: "dishware"), isNew: false, zwjGroup: nil),
    .init(character: "🍴", name: "fork and knife", category: .init(group: "Food & Drink", subgroup: "dishware"), isNew: false, zwjGroup: nil),
    .init(character: "🥄", name: "spoon", category: .init(group: "Food & Drink", subgroup: "dishware"), isNew: false, zwjGroup: nil),
    .init(character: "🔪", name: "kitchen knife", category: .init(group: "Food & Drink", subgroup: "dishware"), isNew: false, zwjGroup: nil),
    .init(character: "🫙", name: "jar", category: .init(group: "Food & Drink", subgroup: "dishware"), isNew: true, zwjGroup: nil),
    .init(character: "🏺", name: "amphora", category: .init(group: "Food & Drink", subgroup: "dishware"), isNew: false, zwjGroup: nil),
    .init(character: "🌍", name: "globe showing Europe-Africa", category: .init(group: "Travel & Places", subgroup: "place-map"), isNew: false, zwjGroup: nil),
    .init(character: "🌎", name: "globe showing Americas", category: .init(group: "Travel & Places", subgroup: "place-map"), isNew: false, zwjGroup: nil),
    .init(character: "🌏", name: "globe showing Asia-Australia", category: .init(group: "Travel & Places", subgroup: "place-map"), isNew: false, zwjGroup: nil),
    .init(character: "🌐", name: "globe with meridians", category: .init(group: "Travel & Places", subgroup: "place-map"), isNew: false, zwjGroup: nil),
    .init(character: "🗺️", name: "world map", category: .init(group: "Travel & Places", subgroup: "place-map"), isNew: false, zwjGroup: nil),
    .init(character: "🗾", name: "map of Japan", category: .init(group: "Travel & Places", subgroup: "place-map"), isNew: false, zwjGroup: nil),
    .init(character: "🧭", name: "compass", category: .init(group: "Travel & Places", subgroup: "place-map"), isNew: false, zwjGroup: nil),
    .init(character: "🏔️", name: "snow-capped mountain", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "⛰️", name: "mountain", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🌋", name: "volcano", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🗻", name: "mount fuji", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🏕️", name: "camping", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🏖️", name: "beach with umbrella", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🏜️", name: "desert", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🏝️", name: "desert island", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🏞️", name: "national park", category: .init(group: "Travel & Places", subgroup: "place-geographic"), isNew: false, zwjGroup: nil),
    .init(character: "🏟️", name: "stadium", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏛️", name: "classical building", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏗️", name: "building construction", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🧱", name: "brick", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🪨", name: "rock", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🪵", name: "wood", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🛖", name: "hut", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏘️", name: "houses", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏚️", name: "derelict house", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏠", name: "house", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏡", name: "house with garden", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏢", name: "office building", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏣", name: "Japanese post office", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏤", name: "post office", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏥", name: "hospital", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏦", name: "bank", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏨", name: "hotel", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏩", name: "love hotel", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏪", name: "convenience store", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏫", name: "school", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏬", name: "department store", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏭", name: "factory", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏯", name: "Japanese castle", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🏰", name: "castle", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "💒", name: "wedding", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🗼", name: "Tokyo tower", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "🗽", name: "Statue of Liberty", category: .init(group: "Travel & Places", subgroup: "place-building"), isNew: false, zwjGroup: nil),
    .init(character: "⛪", name: "church", category: .init(group: "Travel & Places", subgroup: "place-religious"), isNew: false, zwjGroup: nil),
    .init(character: "🕌", name: "mosque", category: .init(group: "Travel & Places", subgroup: "place-religious"), isNew: false, zwjGroup: nil),
    .init(character: "🛕", name: "hindu temple", category: .init(group: "Travel & Places", subgroup: "place-religious"), isNew: false, zwjGroup: nil),
    .init(character: "🕍", name: "synagogue", category: .init(group: "Travel & Places", subgroup: "place-religious"), isNew: false, zwjGroup: nil),
    .init(character: "⛩️", name: "shinto shrine", category: .init(group: "Travel & Places", subgroup: "place-religious"), isNew: false, zwjGroup: nil),
    .init(character: "🕋", name: "kaaba", category: .init(group: "Travel & Places", subgroup: "place-religious"), isNew: false, zwjGroup: nil),
    .init(character: "⛲", name: "fountain", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "⛺", name: "tent", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌁", name: "foggy", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌃", name: "night with stars", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🏙️", name: "cityscape", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌄", name: "sunrise over mountains", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌅", name: "sunrise", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌆", name: "cityscape at dusk", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌇", name: "sunset", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🌉", name: "bridge at night", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "♨️", name: "hot springs", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🎠", name: "carousel horse", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🛝", name: "playground slide", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: true, zwjGroup: nil),
    .init(character: "🎡", name: "ferris wheel", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🎢", name: "roller coaster", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "💈", name: "barber pole", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🎪", name: "circus tent", category: .init(group: "Travel & Places", subgroup: "place-other"), isNew: false, zwjGroup: nil),
    .init(character: "🚂", name: "locomotive", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚃", name: "railway car", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚄", name: "high-speed train", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚅", name: "bullet train", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚆", name: "train", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚇", name: "metro", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚈", name: "light rail", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚉", name: "station", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚊", name: "tram", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚝", name: "monorail", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚞", name: "mountain railway", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚋", name: "tram car", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚌", name: "bus", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚍", name: "oncoming bus", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚎", name: "trolleybus", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚐", name: "minibus", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚑", name: "ambulance", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚒", name: "fire engine", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚓", name: "police car", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚔", name: "oncoming police car", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚕", name: "taxi", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚖", name: "oncoming taxi", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚗", name: "automobile", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚘", name: "oncoming automobile", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚙", name: "sport utility vehicle", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛻", name: "pickup truck", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚚", name: "delivery truck", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚛", name: "articulated lorry", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚜", name: "tractor", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🏎️", name: "racing car", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🏍️", name: "motorcycle", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛵", name: "motor scooter", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🦽", name: "manual wheelchair", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🦼", name: "motorized wheelchair", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛺", name: "auto rickshaw", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚲", name: "bicycle", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛴", name: "kick scooter", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛹", name: "skateboard", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛼", name: "roller skate", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚏", name: "bus stop", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛣️", name: "motorway", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛤️", name: "railway track", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛢️", name: "oil drum", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "⛽", name: "fuel pump", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛞", name: "wheel", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: true, zwjGroup: nil),
    .init(character: "🚨", name: "police car light", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚥", name: "horizontal traffic light", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚦", name: "vertical traffic light", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🛑", name: "stop sign", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "🚧", name: "construction", category: .init(group: "Travel & Places", subgroup: "transport-ground"), isNew: false, zwjGroup: nil),
    .init(character: "⚓", name: "anchor", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "🛟", name: "ring buoy", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: true, zwjGroup: nil),
    .init(character: "⛵", name: "sailboat", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "🛶", name: "canoe", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "🚤", name: "speedboat", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "🛳️", name: "passenger ship", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "⛴️", name: "ferry", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "🛥️", name: "motor boat", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "🚢", name: "ship", category: .init(group: "Travel & Places", subgroup: "transport-water"), isNew: false, zwjGroup: nil),
    .init(character: "✈️", name: "airplane", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🛩️", name: "small airplane", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🛫", name: "airplane departure", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🛬", name: "airplane arrival", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🪂", name: "parachute", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "💺", name: "seat", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🚁", name: "helicopter", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🚟", name: "suspension railway", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🚠", name: "mountain cableway", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🚡", name: "aerial tramway", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🛰️", name: "satellite", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🚀", name: "rocket", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🛸", name: "flying saucer", category: .init(group: "Travel & Places", subgroup: "transport-air"), isNew: false, zwjGroup: nil),
    .init(character: "🛎️", name: "bellhop bell", category: .init(group: "Travel & Places", subgroup: "hotel"), isNew: false, zwjGroup: nil),
    .init(character: "🧳", name: "luggage", category: .init(group: "Travel & Places", subgroup: "hotel"), isNew: false, zwjGroup: nil),
    .init(character: "⌛", name: "hourglass done", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "⏳", name: "hourglass not done", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "⌚", name: "watch", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "⏰", name: "alarm clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "⏱️", name: "stopwatch", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "⏲️", name: "timer clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕰️", name: "mantelpiece clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕛", name: "twelve o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕧", name: "twelve-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕐", name: "one o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕜", name: "one-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕑", name: "two o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕝", name: "two-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕒", name: "three o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕞", name: "three-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕓", name: "four o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕟", name: "four-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕔", name: "five o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕠", name: "five-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕕", name: "six o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕡", name: "six-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕖", name: "seven o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕢", name: "seven-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕗", name: "eight o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕣", name: "eight-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕘", name: "nine o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕤", name: "nine-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕙", name: "ten o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕥", name: "ten-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕚", name: "eleven o’clock", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🕦", name: "eleven-thirty", category: .init(group: "Travel & Places", subgroup: "time"), isNew: false, zwjGroup: nil),
    .init(character: "🌑", name: "new moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌒", name: "waxing crescent moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌓", name: "first quarter moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌔", name: "waxing gibbous moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌕", name: "full moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌖", name: "waning gibbous moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌗", name: "last quarter moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌘", name: "waning crescent moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌙", name: "crescent moon", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌚", name: "new moon face", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌛", name: "first quarter moon face", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌜", name: "last quarter moon face", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌡️", name: "thermometer", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "☀️", name: "sun", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌝", name: "full moon face", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌞", name: "sun with face", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🪐", name: "ringed planet", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "⭐", name: "star", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌟", name: "glowing star", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌠", name: "shooting star", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌌", name: "milky way", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "☁️", name: "cloud", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "⛅", name: "sun behind cloud", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "⛈️", name: "cloud with lightning and rain", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌤️", name: "sun behind small cloud", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌥️", name: "sun behind large cloud", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌦️", name: "sun behind rain cloud", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌧️", name: "cloud with rain", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌨️", name: "cloud with snow", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌩️", name: "cloud with lightning", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌪️", name: "tornado", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌫️", name: "fog", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌬️", name: "wind face", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌀", name: "cyclone", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌈", name: "rainbow", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌂", name: "closed umbrella", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "☂️", name: "umbrella", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "☔", name: "umbrella with rain drops", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "⛱️", name: "umbrella on ground", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "⚡", name: "high voltage", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "❄️", name: "snowflake", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "☃️", name: "snowman", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "⛄", name: "snowman without snow", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "☄️", name: "comet", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🔥", name: "fire", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "💧", name: "droplet", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🌊", name: "water wave", category: .init(group: "Travel & Places", subgroup: "sky & weather"), isNew: false, zwjGroup: nil),
    .init(character: "🎃", name: "jack-o-lantern", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎄", name: "Christmas tree", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎆", name: "fireworks", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎇", name: "sparkler", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🧨", name: "firecracker", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "✨", name: "sparkles", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎈", name: "balloon", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎉", name: "party popper", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎊", name: "confetti ball", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎋", name: "tanabata tree", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎍", name: "pine decoration", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎎", name: "Japanese dolls", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎏", name: "carp streamer", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎐", name: "wind chime", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎑", name: "moon viewing ceremony", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🧧", name: "red envelope", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎀", name: "ribbon", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎁", name: "wrapped gift", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎗️", name: "reminder ribbon", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎟️", name: "admission tickets", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎫", name: "ticket", category: .init(group: "Activities", subgroup: "event"), isNew: false, zwjGroup: nil),
    .init(character: "🎖️", name: "military medal", category: .init(group: "Activities", subgroup: "award-medal"), isNew: false, zwjGroup: nil),
    .init(character: "🏆", name: "trophy", category: .init(group: "Activities", subgroup: "award-medal"), isNew: false, zwjGroup: nil),
    .init(character: "🏅", name: "sports medal", category: .init(group: "Activities", subgroup: "award-medal"), isNew: false, zwjGroup: nil),
    .init(character: "🥇", name: "1st place medal", category: .init(group: "Activities", subgroup: "award-medal"), isNew: false, zwjGroup: nil),
    .init(character: "🥈", name: "2nd place medal", category: .init(group: "Activities", subgroup: "award-medal"), isNew: false, zwjGroup: nil),
    .init(character: "🥉", name: "3rd place medal", category: .init(group: "Activities", subgroup: "award-medal"), isNew: false, zwjGroup: nil),
    .init(character: "⚽", name: "soccer ball", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "⚾", name: "baseball", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🥎", name: "softball", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏀", name: "basketball", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏐", name: "volleyball", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏈", name: "american football", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏉", name: "rugby football", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🎾", name: "tennis", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🥏", name: "flying disc", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🎳", name: "bowling", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏏", name: "cricket game", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏑", name: "field hockey", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏒", name: "ice hockey", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🥍", name: "lacrosse", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏓", name: "ping pong", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🏸", name: "badminton", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🥊", name: "boxing glove", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🥋", name: "martial arts uniform", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🥅", name: "goal net", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛳", name: "flag in hole", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "⛸️", name: "ice skate", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🎣", name: "fishing pole", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🤿", name: "diving mask", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🎽", name: "running shirt", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🎿", name: "skis", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🛷", name: "sled", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🥌", name: "curling stone", category: .init(group: "Activities", subgroup: "sport"), isNew: false, zwjGroup: nil),
    .init(character: "🎯", name: "bullseye", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🪀", name: "yo-yo", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🪁", name: "kite", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🎱", name: "pool 8 ball", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🔮", name: "crystal ball", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🪄", name: "magic wand", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🧿", name: "nazar amulet", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🪬", name: "hamsa", category: .init(group: "Activities", subgroup: "game"), isNew: true, zwjGroup: nil),
    .init(character: "🎮", name: "video game", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🕹️", name: "joystick", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🎰", name: "slot machine", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🎲", name: "game die", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🧩", name: "puzzle piece", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🧸", name: "teddy bear", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🪅", name: "piñata", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🪩", name: "mirror ball", category: .init(group: "Activities", subgroup: "game"), isNew: true, zwjGroup: nil),
    .init(character: "🪆", name: "nesting dolls", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "♠️", name: "spade suit", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "♥️", name: "heart suit", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "♦️", name: "diamond suit", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "♣️", name: "club suit", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "♟️", name: "chess pawn", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🃏", name: "joker", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🀄", name: "mahjong red dragon", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🎴", name: "flower playing cards", category: .init(group: "Activities", subgroup: "game"), isNew: false, zwjGroup: nil),
    .init(character: "🎭", name: "performing arts", category: .init(group: "Activities", subgroup: "arts & crafts"), isNew: false, zwjGroup: nil),
    .init(character: "🖼️", name: "framed picture", category: .init(group: "Activities", subgroup: "arts & crafts"), isNew: false, zwjGroup: nil),
    .init(character: "🎨", name: "artist palette", category: .init(group: "Activities", subgroup: "arts & crafts"), isNew: false, zwjGroup: nil),
    .init(character: "🧵", name: "thread", category: .init(group: "Activities", subgroup: "arts & crafts"), isNew: false, zwjGroup: nil),
    .init(character: "🪡", name: "sewing needle", category: .init(group: "Activities", subgroup: "arts & crafts"), isNew: false, zwjGroup: nil),
    .init(character: "🧶", name: "yarn", category: .init(group: "Activities", subgroup: "arts & crafts"), isNew: false, zwjGroup: nil),
    .init(character: "🪢", name: "knot", category: .init(group: "Activities", subgroup: "arts & crafts"), isNew: false, zwjGroup: nil),
    .init(character: "👓", name: "glasses", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🕶️", name: "sunglasses", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🥽", name: "goggles", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🥼", name: "lab coat", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🦺", name: "safety vest", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👔", name: "necktie", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👕", name: "t-shirt", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👖", name: "jeans", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🧣", name: "scarf", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🧤", name: "gloves", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🧥", name: "coat", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🧦", name: "socks", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👗", name: "dress", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👘", name: "kimono", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🥻", name: "sari", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🩱", name: "one-piece swimsuit", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🩲", name: "briefs", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🩳", name: "shorts", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👙", name: "bikini", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👚", name: "woman’s clothes", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👛", name: "purse", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👜", name: "handbag", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👝", name: "clutch bag", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🛍️", name: "shopping bags", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🎒", name: "backpack", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🩴", name: "thong sandal", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👞", name: "man’s shoe", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👟", name: "running shoe", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🥾", name: "hiking boot", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🥿", name: "flat shoe", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👠", name: "high-heeled shoe", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👡", name: "woman’s sandal", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🩰", name: "ballet shoes", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👢", name: "woman’s boot", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👑", name: "crown", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "👒", name: "woman’s hat", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🎩", name: "top hat", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🎓", name: "graduation cap", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🧢", name: "billed cap", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🪖", name: "military helmet", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "⛑️", name: "rescue worker’s helmet", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "📿", name: "prayer beads", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "💄", name: "lipstick", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "💍", name: "ring", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "💎", name: "gem stone", category: .init(group: "Objects", subgroup: "clothing"), isNew: false, zwjGroup: nil),
    .init(character: "🔇", name: "muted speaker", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "🔈", name: "speaker low volume", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "🔉", name: "speaker medium volume", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "🔊", name: "speaker high volume", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "📢", name: "loudspeaker", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "📣", name: "megaphone", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "📯", name: "postal horn", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "🔔", name: "bell", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "🔕", name: "bell with slash", category: .init(group: "Objects", subgroup: "sound"), isNew: false, zwjGroup: nil),
    .init(character: "🎼", name: "musical score", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎵", name: "musical note", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎶", name: "musical notes", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎙️", name: "studio microphone", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎚️", name: "level slider", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎛️", name: "control knobs", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎤", name: "microphone", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎧", name: "headphone", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "📻", name: "radio", category: .init(group: "Objects", subgroup: "music"), isNew: false, zwjGroup: nil),
    .init(character: "🎷", name: "saxophone", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🪗", name: "accordion", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🎸", name: "guitar", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🎹", name: "musical keyboard", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🎺", name: "trumpet", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🎻", name: "violin", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🪕", name: "banjo", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🥁", name: "drum", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "🪘", name: "long drum", category: .init(group: "Objects", subgroup: "musical-instrument"), isNew: false, zwjGroup: nil),
    .init(character: "📱", name: "mobile phone", category: .init(group: "Objects", subgroup: "phone"), isNew: false, zwjGroup: nil),
    .init(character: "📲", name: "mobile phone with arrow", category: .init(group: "Objects", subgroup: "phone"), isNew: false, zwjGroup: nil),
    .init(character: "☎️", name: "telephone", category: .init(group: "Objects", subgroup: "phone"), isNew: false, zwjGroup: nil),
    .init(character: "📞", name: "telephone receiver", category: .init(group: "Objects", subgroup: "phone"), isNew: false, zwjGroup: nil),
    .init(character: "📟", name: "pager", category: .init(group: "Objects", subgroup: "phone"), isNew: false, zwjGroup: nil),
    .init(character: "📠", name: "fax machine", category: .init(group: "Objects", subgroup: "phone"), isNew: false, zwjGroup: nil),
    .init(character: "🔋", name: "battery", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "🪫", name: "low battery", category: .init(group: "Objects", subgroup: "computer"), isNew: true, zwjGroup: nil),
    .init(character: "🔌", name: "electric plug", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "💻", name: "laptop", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "🖥️", name: "desktop computer", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "🖨️", name: "printer", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "⌨️", name: "keyboard", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "🖱️", name: "computer mouse", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "🖲️", name: "trackball", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "💽", name: "computer disk", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "💾", name: "floppy disk", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "💿", name: "optical disk", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "📀", name: "dvd", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "🧮", name: "abacus", category: .init(group: "Objects", subgroup: "computer"), isNew: false, zwjGroup: nil),
    .init(character: "🎥", name: "movie camera", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🎞️", name: "film frames", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "📽️", name: "film projector", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🎬", name: "clapper board", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "📺", name: "television", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "📷", name: "camera", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "📸", name: "camera with flash", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "📹", name: "video camera", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "📼", name: "videocassette", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🔍", name: "magnifying glass tilted left", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🔎", name: "magnifying glass tilted right", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🕯️", name: "candle", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "💡", name: "light bulb", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🔦", name: "flashlight", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🏮", name: "red paper lantern", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "🪔", name: "diya lamp", category: .init(group: "Objects", subgroup: "light & video"), isNew: false, zwjGroup: nil),
    .init(character: "📔", name: "notebook with decorative cover", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📕", name: "closed book", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📖", name: "open book", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📗", name: "green book", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📘", name: "blue book", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📙", name: "orange book", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📚", name: "books", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📓", name: "notebook", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📒", name: "ledger", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📃", name: "page with curl", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📜", name: "scroll", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📄", name: "page facing up", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📰", name: "newspaper", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "🗞️", name: "rolled-up newspaper", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "📑", name: "bookmark tabs", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "🔖", name: "bookmark", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "🏷️", name: "label", category: .init(group: "Objects", subgroup: "book-paper"), isNew: false, zwjGroup: nil),
    .init(character: "💰", name: "money bag", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "🪙", name: "coin", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "💴", name: "yen banknote", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "💵", name: "dollar banknote", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "💶", name: "euro banknote", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "💷", name: "pound banknote", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "💸", name: "money with wings", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "💳", name: "credit card", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "🧾", name: "receipt", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "💹", name: "chart increasing with yen", category: .init(group: "Objects", subgroup: "money"), isNew: false, zwjGroup: nil),
    .init(character: "✉️", name: "envelope", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📧", name: "e-mail", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📨", name: "incoming envelope", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📩", name: "envelope with arrow", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📤", name: "outbox tray", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📥", name: "inbox tray", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📦", name: "package", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📫", name: "closed mailbox with raised flag", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📪", name: "closed mailbox with lowered flag", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📬", name: "open mailbox with raised flag", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📭", name: "open mailbox with lowered flag", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "📮", name: "postbox", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "🗳️", name: "ballot box with ballot", category: .init(group: "Objects", subgroup: "mail"), isNew: false, zwjGroup: nil),
    .init(character: "✏️", name: "pencil", category: .init(group: "Objects", subgroup: "writing"), isNew: false, zwjGroup: nil),
    .init(character: "✒️", name: "black nib", category: .init(group: "Objects", subgroup: "writing"), isNew: false, zwjGroup: nil),
    .init(character: "🖋️", name: "fountain pen", category: .init(group: "Objects", subgroup: "writing"), isNew: false, zwjGroup: nil),
    .init(character: "🖊️", name: "pen", category: .init(group: "Objects", subgroup: "writing"), isNew: false, zwjGroup: nil),
    .init(character: "🖌️", name: "paintbrush", category: .init(group: "Objects", subgroup: "writing"), isNew: false, zwjGroup: nil),
    .init(character: "🖍️", name: "crayon", category: .init(group: "Objects", subgroup: "writing"), isNew: false, zwjGroup: nil),
    .init(character: "📝", name: "memo", category: .init(group: "Objects", subgroup: "writing"), isNew: false, zwjGroup: nil),
    .init(character: "💼", name: "briefcase", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📁", name: "file folder", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📂", name: "open file folder", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🗂️", name: "card index dividers", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📅", name: "calendar", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📆", name: "tear-off calendar", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🗒️", name: "spiral notepad", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🗓️", name: "spiral calendar", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📇", name: "card index", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📈", name: "chart increasing", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📉", name: "chart decreasing", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📊", name: "bar chart", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📋", name: "clipboard", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📌", name: "pushpin", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📍", name: "round pushpin", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📎", name: "paperclip", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🖇️", name: "linked paperclips", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📏", name: "straight ruler", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "📐", name: "triangular ruler", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "✂️", name: "scissors", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🗃️", name: "card file box", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🗄️", name: "file cabinet", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🗑️", name: "wastebasket", category: .init(group: "Objects", subgroup: "office"), isNew: false, zwjGroup: nil),
    .init(character: "🔒", name: "locked", category: .init(group: "Objects", subgroup: "lock"), isNew: false, zwjGroup: nil),
    .init(character: "🔓", name: "unlocked", category: .init(group: "Objects", subgroup: "lock"), isNew: false, zwjGroup: nil),
    .init(character: "🔏", name: "locked with pen", category: .init(group: "Objects", subgroup: "lock"), isNew: false, zwjGroup: nil),
    .init(character: "🔐", name: "locked with key", category: .init(group: "Objects", subgroup: "lock"), isNew: false, zwjGroup: nil),
    .init(character: "🔑", name: "key", category: .init(group: "Objects", subgroup: "lock"), isNew: false, zwjGroup: nil),
    .init(character: "🗝️", name: "old key", category: .init(group: "Objects", subgroup: "lock"), isNew: false, zwjGroup: nil),
    .init(character: "🔨", name: "hammer", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🪓", name: "axe", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "⛏️", name: "pick", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "⚒️", name: "hammer and pick", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🛠️", name: "hammer and wrench", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🗡️", name: "dagger", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "⚔️", name: "crossed swords", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🔫", name: "water pistol", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🪃", name: "boomerang", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🏹", name: "bow and arrow", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🛡️", name: "shield", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🪚", name: "carpentry saw", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🔧", name: "wrench", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🪛", name: "screwdriver", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🔩", name: "nut and bolt", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "⚙️", name: "gear", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🗜️", name: "clamp", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "⚖️", name: "balance scale", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🦯", name: "white cane", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🔗", name: "link", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "⛓️", name: "chains", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🪝", name: "hook", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🧰", name: "toolbox", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🧲", name: "magnet", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "🪜", name: "ladder", category: .init(group: "Objects", subgroup: "tool"), isNew: false, zwjGroup: nil),
    .init(character: "⚗️", name: "alembic", category: .init(group: "Objects", subgroup: "science"), isNew: false, zwjGroup: nil),
    .init(character: "🧪", name: "test tube", category: .init(group: "Objects", subgroup: "science"), isNew: false, zwjGroup: nil),
    .init(character: "🧫", name: "petri dish", category: .init(group: "Objects", subgroup: "science"), isNew: false, zwjGroup: nil),
    .init(character: "🧬", name: "dna", category: .init(group: "Objects", subgroup: "science"), isNew: false, zwjGroup: nil),
    .init(character: "🔬", name: "microscope", category: .init(group: "Objects", subgroup: "science"), isNew: false, zwjGroup: nil),
    .init(character: "🔭", name: "telescope", category: .init(group: "Objects", subgroup: "science"), isNew: false, zwjGroup: nil),
    .init(character: "📡", name: "satellite antenna", category: .init(group: "Objects", subgroup: "science"), isNew: false, zwjGroup: nil),
    .init(character: "💉", name: "syringe", category: .init(group: "Objects", subgroup: "medical"), isNew: false, zwjGroup: nil),
    .init(character: "🩸", name: "drop of blood", category: .init(group: "Objects", subgroup: "medical"), isNew: false, zwjGroup: nil),
    .init(character: "💊", name: "pill", category: .init(group: "Objects", subgroup: "medical"), isNew: false, zwjGroup: nil),
    .init(character: "🩹", name: "adhesive bandage", category: .init(group: "Objects", subgroup: "medical"), isNew: false, zwjGroup: nil),
    .init(character: "🩼", name: "crutch", category: .init(group: "Objects", subgroup: "medical"), isNew: true, zwjGroup: nil),
    .init(character: "🩺", name: "stethoscope", category: .init(group: "Objects", subgroup: "medical"), isNew: false, zwjGroup: nil),
    .init(character: "🩻", name: "x-ray", category: .init(group: "Objects", subgroup: "medical"), isNew: true, zwjGroup: nil),
    .init(character: "🚪", name: "door", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🛗", name: "elevator", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🪞", name: "mirror", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🪟", name: "window", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🛏️", name: "bed", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🛋️", name: "couch and lamp", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🪑", name: "chair", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🚽", name: "toilet", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🪠", name: "plunger", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🚿", name: "shower", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🛁", name: "bathtub", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🪤", name: "mouse trap", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🪒", name: "razor", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧴", name: "lotion bottle", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧷", name: "safety pin", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧹", name: "broom", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧺", name: "basket", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧻", name: "roll of paper", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🪣", name: "bucket", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧼", name: "soap", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🫧", name: "bubbles", category: .init(group: "Objects", subgroup: "household"), isNew: true, zwjGroup: nil),
    .init(character: "🪥", name: "toothbrush", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧽", name: "sponge", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🧯", name: "fire extinguisher", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🛒", name: "shopping cart", category: .init(group: "Objects", subgroup: "household"), isNew: false, zwjGroup: nil),
    .init(character: "🚬", name: "cigarette", category: .init(group: "Objects", subgroup: "other-object"), isNew: false, zwjGroup: nil),
    .init(character: "⚰️", name: "coffin", category: .init(group: "Objects", subgroup: "other-object"), isNew: false, zwjGroup: nil),
    .init(character: "🪦", name: "headstone", category: .init(group: "Objects", subgroup: "other-object"), isNew: false, zwjGroup: nil),
    .init(character: "⚱️", name: "funeral urn", category: .init(group: "Objects", subgroup: "other-object"), isNew: false, zwjGroup: nil),
    .init(character: "🗿", name: "moai", category: .init(group: "Objects", subgroup: "other-object"), isNew: false, zwjGroup: nil),
    .init(character: "🪧", name: "placard", category: .init(group: "Objects", subgroup: "other-object"), isNew: false, zwjGroup: nil),
    .init(character: "🪪", name: "identification card", category: .init(group: "Objects", subgroup: "other-object"), isNew: true, zwjGroup: nil),
    .init(character: "🏧", name: "ATM sign", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🚮", name: "litter in bin sign", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🚰", name: "potable water", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "♿", name: "wheelchair symbol", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🚹", name: "men’s room", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🚺", name: "women’s room", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🚻", name: "restroom", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🚼", name: "baby symbol", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🚾", name: "water closet", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🛂", name: "passport control", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🛃", name: "customs", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🛄", name: "baggage claim", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "🛅", name: "left luggage", category: .init(group: "Symbols", subgroup: "transport-sign"), isNew: false, zwjGroup: nil),
    .init(character: "⚠️", name: "warning", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🚸", name: "children crossing", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "⛔", name: "no entry", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🚫", name: "prohibited", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🚳", name: "no bicycles", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🚭", name: "no smoking", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🚯", name: "no littering", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🚱", name: "non-potable water", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🚷", name: "no pedestrians", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "📵", name: "no mobile phones", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "🔞", name: "no one under eighteen", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "☢️", name: "radioactive", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "☣️", name: "biohazard", category: .init(group: "Symbols", subgroup: "warning"), isNew: false, zwjGroup: nil),
    .init(character: "⬆️", name: "up arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↗️", name: "up-right arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "➡️", name: "right arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↘️", name: "down-right arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "⬇️", name: "down arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↙️", name: "down-left arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "⬅️", name: "left arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↖️", name: "up-left arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↕️", name: "up-down arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↔️", name: "left-right arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↩️", name: "right arrow curving left", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "↪️", name: "left arrow curving right", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "⤴️", name: "right arrow curving up", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "⤵️", name: "right arrow curving down", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🔃", name: "clockwise vertical arrows", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🔄", name: "counterclockwise arrows button", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🔙", name: "BACK arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🔚", name: "END arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🔛", name: "ON! arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🔜", name: "SOON arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🔝", name: "TOP arrow", category: .init(group: "Symbols", subgroup: "arrow"), isNew: false, zwjGroup: nil),
    .init(character: "🛐", name: "place of worship", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "⚛️", name: "atom symbol", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "🕉️", name: "om", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "✡️", name: "star of David", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "☸️", name: "wheel of dharma", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "☯️", name: "yin yang", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "✝️", name: "latin cross", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "☦️", name: "orthodox cross", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "☪️", name: "star and crescent", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "☮️", name: "peace symbol", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "🕎", name: "menorah", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "🔯", name: "dotted six-pointed star", category: .init(group: "Symbols", subgroup: "religion"), isNew: false, zwjGroup: nil),
    .init(character: "♈", name: "Aries", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♉", name: "Taurus", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♊", name: "Gemini", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♋", name: "Cancer", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♌", name: "Leo", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♍", name: "Virgo", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♎", name: "Libra", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♏", name: "Scorpio", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♐", name: "Sagittarius", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♑", name: "Capricorn", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♒", name: "Aquarius", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "♓", name: "Pisces", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "⛎", name: "Ophiuchus", category: .init(group: "Symbols", subgroup: "zodiac"), isNew: false, zwjGroup: nil),
    .init(character: "🔀", name: "shuffle tracks button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔁", name: "repeat button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔂", name: "repeat single button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "▶️", name: "play button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏩", name: "fast-forward button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏭️", name: "next track button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏯️", name: "play or pause button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "◀️", name: "reverse button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏪", name: "fast reverse button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏮️", name: "last track button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔼", name: "upwards button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏫", name: "fast up button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔽", name: "downwards button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏬", name: "fast down button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏸️", name: "pause button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏹️", name: "stop button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏺️", name: "record button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⏏️", name: "eject button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🎦", name: "cinema", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔅", name: "dim button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔆", name: "bright button", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "📶", name: "antenna bars", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "📳", name: "vibration mode", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "📴", name: "mobile phone off", category: .init(group: "Symbols", subgroup: "av-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "♀️", name: "female sign", category: .init(group: "Symbols", subgroup: "gender"), isNew: false, zwjGroup: nil),
    .init(character: "♂️", name: "male sign", category: .init(group: "Symbols", subgroup: "gender"), isNew: false, zwjGroup: nil),
    .init(character: "⚧️", name: "transgender symbol", category: .init(group: "Symbols", subgroup: "gender"), isNew: false, zwjGroup: nil),
    .init(character: "✖️", name: "multiply", category: .init(group: "Symbols", subgroup: "math"), isNew: false, zwjGroup: nil),
    .init(character: "➕", name: "plus", category: .init(group: "Symbols", subgroup: "math"), isNew: false, zwjGroup: nil),
    .init(character: "➖", name: "minus", category: .init(group: "Symbols", subgroup: "math"), isNew: false, zwjGroup: nil),
    .init(character: "➗", name: "divide", category: .init(group: "Symbols", subgroup: "math"), isNew: false, zwjGroup: nil),
    .init(character: "🟰", name: "heavy equals sign", category: .init(group: "Symbols", subgroup: "math"), isNew: true, zwjGroup: nil),
    .init(character: "♾️", name: "infinity", category: .init(group: "Symbols", subgroup: "math"), isNew: false, zwjGroup: nil),
    .init(character: "‼️", name: "double exclamation mark", category: .init(group: "Symbols", subgroup: "punctuation"), isNew: false, zwjGroup: nil),
    .init(character: "⁉️", name: "exclamation question mark", category: .init(group: "Symbols", subgroup: "punctuation"), isNew: false, zwjGroup: nil),
    .init(character: "❓", name: "red question mark", category: .init(group: "Symbols", subgroup: "punctuation"), isNew: false, zwjGroup: nil),
    .init(character: "❔", name: "white question mark", category: .init(group: "Symbols", subgroup: "punctuation"), isNew: false, zwjGroup: nil),
    .init(character: "❕", name: "white exclamation mark", category: .init(group: "Symbols", subgroup: "punctuation"), isNew: false, zwjGroup: nil),
    .init(character: "❗", name: "red exclamation mark", category: .init(group: "Symbols", subgroup: "punctuation"), isNew: false, zwjGroup: nil),
    .init(character: "〰️", name: "wavy dash", category: .init(group: "Symbols", subgroup: "punctuation"), isNew: false, zwjGroup: nil),
    .init(character: "💱", name: "currency exchange", category: .init(group: "Symbols", subgroup: "currency"), isNew: false, zwjGroup: nil),
    .init(character: "💲", name: "heavy dollar sign", category: .init(group: "Symbols", subgroup: "currency"), isNew: false, zwjGroup: nil),
    .init(character: "⚕️", name: "medical symbol", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "♻️", name: "recycling symbol", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⚜️", name: "fleur-de-lis", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔱", name: "trident emblem", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "📛", name: "name badge", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "🔰", name: "Japanese symbol for beginner", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "⭕", name: "hollow red circle", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "✅", name: "check mark button", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "☑️", name: "check box with check", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "✔️", name: "check mark", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "❌", name: "cross mark", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "❎", name: "cross mark button", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "➰", name: "curly loop", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "➿", name: "double curly loop", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "〽️", name: "part alternation mark", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "✳️", name: "eight-spoked asterisk", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "✴️", name: "eight-pointed star", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "❇️", name: "sparkle", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "©️", name: "copyright", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "®️", name: "registered", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "™️", name: "trade mark", category: .init(group: "Symbols", subgroup: "other-symbol"), isNew: false, zwjGroup: nil),
    .init(character: "#️⃣", name: "keycap: #", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "*️⃣", name: "keycap: *", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "0️⃣", name: "keycap: 0", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "1️⃣", name: "keycap: 1", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "2️⃣", name: "keycap: 2", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "3️⃣", name: "keycap: 3", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "4️⃣", name: "keycap: 4", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "5️⃣", name: "keycap: 5", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "6️⃣", name: "keycap: 6", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "7️⃣", name: "keycap: 7", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "8️⃣", name: "keycap: 8", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "9️⃣", name: "keycap: 9", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "🔟", name: "keycap: 10", category: .init(group: "Symbols", subgroup: "keycap"), isNew: false, zwjGroup: nil),
    .init(character: "🔠", name: "input latin uppercase", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🔡", name: "input latin lowercase", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🔢", name: "input numbers", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🔣", name: "input symbols", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🔤", name: "input latin letters", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🅰️", name: "A button (blood type)", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆎", name: "AB button (blood type)", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🅱️", name: "B button (blood type)", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆑", name: "CL button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆒", name: "COOL button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆓", name: "FREE button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "ℹ️", name: "information", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆔", name: "ID button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "Ⓜ️", name: "circled M", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆕", name: "NEW button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆖", name: "NG button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🅾️", name: "O button (blood type)", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆗", name: "OK button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🅿️", name: "P button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆘", name: "SOS button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆙", name: "UP! button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🆚", name: "VS button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈁", name: "Japanese “here” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈂️", name: "Japanese “service charge” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈷️", name: "Japanese “monthly amount” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈶", name: "Japanese “not free of charge” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈯", name: "Japanese “reserved” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🉐", name: "Japanese “bargain” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈹", name: "Japanese “discount” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈚", name: "Japanese “free of charge” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈲", name: "Japanese “prohibited” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🉑", name: "Japanese “acceptable” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈸", name: "Japanese “application” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈴", name: "Japanese “passing grade” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈳", name: "Japanese “vacancy” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "㊗️", name: "Japanese “congratulations” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "㊙️", name: "Japanese “secret” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈺", name: "Japanese “open for business” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🈵", name: "Japanese “no vacancy” button", category: .init(group: "Symbols", subgroup: "alphanum"), isNew: false, zwjGroup: nil),
    .init(character: "🔴", name: "red circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟠", name: "orange circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟡", name: "yellow circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟢", name: "green circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔵", name: "blue circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟣", name: "purple circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟤", name: "brown circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "⚫", name: "black circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "⚪", name: "white circle", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟥", name: "red square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟧", name: "orange square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟨", name: "yellow square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟩", name: "green square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟦", name: "blue square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟪", name: "purple square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🟫", name: "brown square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "⬛", name: "black large square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "⬜", name: "white large square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "◼️", name: "black medium square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "◻️", name: "white medium square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "◾", name: "black medium-small square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "◽", name: "white medium-small square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "▪️", name: "black small square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "▫️", name: "white small square", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔶", name: "large orange diamond", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔷", name: "large blue diamond", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔸", name: "small orange diamond", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔹", name: "small blue diamond", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔺", name: "red triangle pointed up", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔻", name: "red triangle pointed down", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "💠", name: "diamond with a dot", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔘", name: "radio button", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔳", name: "white square button", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🔲", name: "black square button", category: .init(group: "Symbols", subgroup: "geometric"), isNew: false, zwjGroup: nil),
    .init(character: "🏁", name: "chequered flag", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: nil),
    .init(character: "🚩", name: "triangular flag", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: nil),
    .init(character: "🎌", name: "crossed flags", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: nil),
    .init(character: "🏴", name: "black flag", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: nil),
    .init(character: "🏳️", name: "white flag", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: nil),
    .init(character: "🏳️‍🌈", name: "rainbow flag", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: "Other"),
    .init(character: "🏳️‍⚧️", name: "transgender flag", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: "Other"),
    .init(character: "🏴‍☠️", name: "pirate flag", category: .init(group: "Flags", subgroup: "flag"), isNew: false, zwjGroup: "Other"),
    .init(character: "🇦🇨", name: "flag: Ascension Island", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇩", name: "flag: Andorra", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇪", name: "flag: United Arab Emirates", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇫", name: "flag: Afghanistan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇬", name: "flag: Antigua & Barbuda", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇮", name: "flag: Anguilla", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇱", name: "flag: Albania", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇲", name: "flag: Armenia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇴", name: "flag: Angola", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇶", name: "flag: Antarctica", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇷", name: "flag: Argentina", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇸", name: "flag: American Samoa", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇹", name: "flag: Austria", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇺", name: "flag: Australia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇼", name: "flag: Aruba", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇽", name: "flag: Åland Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇦🇿", name: "flag: Azerbaijan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇦", name: "flag: Bosnia & Herzegovina", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇧", name: "flag: Barbados", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇩", name: "flag: Bangladesh", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇪", name: "flag: Belgium", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇫", name: "flag: Burkina Faso", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇬", name: "flag: Bulgaria", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇭", name: "flag: Bahrain", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇮", name: "flag: Burundi", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇯", name: "flag: Benin", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇱", name: "flag: St. Barthélemy", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇲", name: "flag: Bermuda", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇳", name: "flag: Brunei", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇴", name: "flag: Bolivia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇶", name: "flag: Caribbean Netherlands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇷", name: "flag: Brazil", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇸", name: "flag: Bahamas", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇹", name: "flag: Bhutan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇻", name: "flag: Bouvet Island", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇼", name: "flag: Botswana", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇾", name: "flag: Belarus", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇧🇿", name: "flag: Belize", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇦", name: "flag: Canada", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇨", name: "flag: Cocos (Keeling) Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇩", name: "flag: Congo - Kinshasa", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇫", name: "flag: Central African Republic", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇬", name: "flag: Congo - Brazzaville", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇭", name: "flag: Switzerland", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇮", name: "flag: Côte d’Ivoire", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇰", name: "flag: Cook Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇱", name: "flag: Chile", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇲", name: "flag: Cameroon", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇳", name: "flag: China", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇴", name: "flag: Colombia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇵", name: "flag: Clipperton Island", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇷", name: "flag: Costa Rica", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇺", name: "flag: Cuba", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇻", name: "flag: Cape Verde", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇼", name: "flag: Curaçao", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇽", name: "flag: Christmas Island", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇾", name: "flag: Cyprus", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇨🇿", name: "flag: Czechia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇩🇪", name: "flag: Germany", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇩🇬", name: "flag: Diego Garcia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇩🇯", name: "flag: Djibouti", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇩🇰", name: "flag: Denmark", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇩🇲", name: "flag: Dominica", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇩🇴", name: "flag: Dominican Republic", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇩🇿", name: "flag: Algeria", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇦", name: "flag: Ceuta & Melilla", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇨", name: "flag: Ecuador", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇪", name: "flag: Estonia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇬", name: "flag: Egypt", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇭", name: "flag: Western Sahara", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇷", name: "flag: Eritrea", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇸", name: "flag: Spain", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇹", name: "flag: Ethiopia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇪🇺", name: "flag: European Union", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇫🇮", name: "flag: Finland", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇫🇯", name: "flag: Fiji", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇫🇰", name: "flag: Falkland Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇫🇲", name: "flag: Micronesia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇫🇴", name: "flag: Faroe Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇫🇷", name: "flag: France", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇦", name: "flag: Gabon", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇧", name: "flag: United Kingdom", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇩", name: "flag: Grenada", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇪", name: "flag: Georgia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇫", name: "flag: French Guiana", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇬", name: "flag: Guernsey", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇭", name: "flag: Ghana", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇮", name: "flag: Gibraltar", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇱", name: "flag: Greenland", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇲", name: "flag: Gambia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇳", name: "flag: Guinea", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇵", name: "flag: Guadeloupe", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇶", name: "flag: Equatorial Guinea", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇷", name: "flag: Greece", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇸", name: "flag: South Georgia & South Sandwich Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇹", name: "flag: Guatemala", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇺", name: "flag: Guam", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇼", name: "flag: Guinea-Bissau", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇬🇾", name: "flag: Guyana", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇭🇰", name: "flag: Hong Kong SAR China", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇭🇲", name: "flag: Heard & McDonald Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇭🇳", name: "flag: Honduras", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇭🇷", name: "flag: Croatia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇭🇹", name: "flag: Haiti", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇭🇺", name: "flag: Hungary", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇨", name: "flag: Canary Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇩", name: "flag: Indonesia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇪", name: "flag: Ireland", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇱", name: "flag: Israel", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇲", name: "flag: Isle of Man", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇳", name: "flag: India", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇴", name: "flag: British Indian Ocean Territory", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇶", name: "flag: Iraq", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇷", name: "flag: Iran", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇸", name: "flag: Iceland", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇮🇹", name: "flag: Italy", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇯🇪", name: "flag: Jersey", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇯🇲", name: "flag: Jamaica", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇯🇴", name: "flag: Jordan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇯🇵", name: "flag: Japan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇪", name: "flag: Kenya", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇬", name: "flag: Kyrgyzstan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇭", name: "flag: Cambodia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇮", name: "flag: Kiribati", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇲", name: "flag: Comoros", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇳", name: "flag: St. Kitts & Nevis", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇵", name: "flag: North Korea", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇷", name: "flag: South Korea", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇼", name: "flag: Kuwait", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇾", name: "flag: Cayman Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇰🇿", name: "flag: Kazakhstan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇦", name: "flag: Laos", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇧", name: "flag: Lebanon", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇨", name: "flag: St. Lucia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇮", name: "flag: Liechtenstein", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇰", name: "flag: Sri Lanka", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇷", name: "flag: Liberia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇸", name: "flag: Lesotho", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇹", name: "flag: Lithuania", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇺", name: "flag: Luxembourg", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇻", name: "flag: Latvia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇱🇾", name: "flag: Libya", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇦", name: "flag: Morocco", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇨", name: "flag: Monaco", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇩", name: "flag: Moldova", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇪", name: "flag: Montenegro", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇫", name: "flag: St. Martin", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇬", name: "flag: Madagascar", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇭", name: "flag: Marshall Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇰", name: "flag: North Macedonia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇱", name: "flag: Mali", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇲", name: "flag: Myanmar (Burma)", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇳", name: "flag: Mongolia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇴", name: "flag: Macao SAR China", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇵", name: "flag: Northern Mariana Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇶", name: "flag: Martinique", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇷", name: "flag: Mauritania", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇸", name: "flag: Montserrat", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇹", name: "flag: Malta", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇺", name: "flag: Mauritius", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇻", name: "flag: Maldives", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇼", name: "flag: Malawi", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇽", name: "flag: Mexico", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇾", name: "flag: Malaysia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇲🇿", name: "flag: Mozambique", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇦", name: "flag: Namibia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇨", name: "flag: New Caledonia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇪", name: "flag: Niger", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇫", name: "flag: Norfolk Island", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇬", name: "flag: Nigeria", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇮", name: "flag: Nicaragua", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇱", name: "flag: Netherlands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇴", name: "flag: Norway", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇵", name: "flag: Nepal", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇷", name: "flag: Nauru", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇺", name: "flag: Niue", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇳🇿", name: "flag: New Zealand", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇴🇲", name: "flag: Oman", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇦", name: "flag: Panama", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇪", name: "flag: Peru", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇫", name: "flag: French Polynesia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇬", name: "flag: Papua New Guinea", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇭", name: "flag: Philippines", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇰", name: "flag: Pakistan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇱", name: "flag: Poland", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇲", name: "flag: St. Pierre & Miquelon", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇳", name: "flag: Pitcairn Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇷", name: "flag: Puerto Rico", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇸", name: "flag: Palestinian Territories", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇹", name: "flag: Portugal", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇼", name: "flag: Palau", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇵🇾", name: "flag: Paraguay", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇶🇦", name: "flag: Qatar", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇷🇪", name: "flag: Réunion", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇷🇴", name: "flag: Romania", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇷🇸", name: "flag: Serbia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇷🇺", name: "flag: Russia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇷🇼", name: "flag: Rwanda", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇦", name: "flag: Saudi Arabia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇧", name: "flag: Solomon Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇨", name: "flag: Seychelles", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇩", name: "flag: Sudan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇪", name: "flag: Sweden", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇬", name: "flag: Singapore", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇭", name: "flag: St. Helena", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇮", name: "flag: Slovenia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇯", name: "flag: Svalbard & Jan Mayen", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇰", name: "flag: Slovakia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇱", name: "flag: Sierra Leone", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇲", name: "flag: San Marino", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇳", name: "flag: Senegal", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇴", name: "flag: Somalia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇷", name: "flag: Suriname", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇸", name: "flag: South Sudan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇹", name: "flag: São Tomé & Príncipe", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇻", name: "flag: El Salvador", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇽", name: "flag: Sint Maarten", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇾", name: "flag: Syria", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇸🇿", name: "flag: Eswatini", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇦", name: "flag: Tristan da Cunha", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇨", name: "flag: Turks & Caicos Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇩", name: "flag: Chad", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇫", name: "flag: French Southern Territories", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇬", name: "flag: Togo", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇭", name: "flag: Thailand", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇯", name: "flag: Tajikistan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇰", name: "flag: Tokelau", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇱", name: "flag: Timor-Leste", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇲", name: "flag: Turkmenistan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇳", name: "flag: Tunisia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇴", name: "flag: Tonga", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇷", name: "flag: Turkey", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇹", name: "flag: Trinidad & Tobago", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇻", name: "flag: Tuvalu", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇼", name: "flag: Taiwan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇹🇿", name: "flag: Tanzania", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇺🇦", name: "flag: Ukraine", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇺🇬", name: "flag: Uganda", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇺🇲", name: "flag: U.S. Outlying Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇺🇳", name: "flag: United Nations", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇺🇸", name: "flag: United States", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇺🇾", name: "flag: Uruguay", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇺🇿", name: "flag: Uzbekistan", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇻🇦", name: "flag: Vatican City", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇻🇨", name: "flag: St. Vincent & Grenadines", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇻🇪", name: "flag: Venezuela", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇻🇬", name: "flag: British Virgin Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇻🇮", name: "flag: U.S. Virgin Islands", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇻🇳", name: "flag: Vietnam", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇻🇺", name: "flag: Vanuatu", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇼🇫", name: "flag: Wallis & Futuna", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇼🇸", name: "flag: Samoa", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇽🇰", name: "flag: Kosovo", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇾🇪", name: "flag: Yemen", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇾🇹", name: "flag: Mayotte", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇿🇦", name: "flag: South Africa", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇿🇲", name: "flag: Zambia", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🇿🇼", name: "flag: Zimbabwe", category: .init(group: "Flags", subgroup: "country-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🏴󠁧󠁢󠁥󠁮󠁧󠁿", name: "flag: England", category: .init(group: "Flags", subgroup: "subdivision-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🏴󠁧󠁢󠁳󠁣󠁴󠁿", name: "flag: Scotland", category: .init(group: "Flags", subgroup: "subdivision-flag"), isNew: false, zwjGroup: nil),
    .init(character: "🏴󠁧󠁢󠁷󠁬󠁳󠁿", name: "flag: Wales", category: .init(group: "Flags", subgroup: "subdivision-flag"), isNew: false, zwjGroup: nil)
]
